function [residual, g1, g2, g3] = cycle_irf_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(70, 1);
T53 = params(2)*exp(y(89))/exp(y(48));
T112 = exp(y(54))*exp(y(20))^params(20)*exp(y(1))^params(10);
T116 = exp(y(10))^(1-params(10));
T174 = params(2)*(1-params(13))*exp(y(89))/exp(y(48));
T200 = exp(.5*(params(14)-exp(y(36)))/(exp(y(36))*params(14)*params(15)));
T220 = 1/exp(y(38))*exp(y(29))/exp(y(36));
T240 = y(63)*exp(y(44))*exp(y(21))*exp(y(36))/(1-exp(y(21)));
T255 = 1-params(12)/2*y(33)^2;
T274 = exp(y(14))/exp(y(2));
T277 = exp(y(32))*(T255-params(12)*y(33)*T274);
T284 = exp(y(79))/exp(y(14));
T287 = exp(y(84))*T53*params(12)*y(85)*T284^2;
T326 = exp(y(89))/exp(y(48))*params(2)*(1-params(5))*(1-params(13))*exp(y(18));
T328 = exp(y(82))*(1-exp(y(80)))*T326;
T336 = exp(y(44))*exp(y(37))/exp(y(16));
T384 = params(20)*params(9)^2;
T394 = (-0.5)*params(11)^0.5*exp(params(20)*0.5*(2*params(8)+T384)/(1-2*params(10)+params(10)^2));
T410 = 0.7071067811865475/params(9)*(params(8)+T384+(-log(exp(y(15))))+params(10)*log(exp(y(15)))-params(10)*params(8))/((-1)+params(10));
T430 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T432 = T394*(erf(T410)-erf(0.7071067811865475*(params(8)+T384+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T430/params(11)^0.5;
T452 = exp(y(42))*(1-params(10))*exp(y(31))/exp(y(10));
T455 = exp(y(15))/exp(y(20));
T464 = exp(y(42))*params(10)*exp(y(31))/exp(y(1));
T590 = params(6)/(1-params(6));
T595 = exp(y(18))*y(63)*exp(y(89))*params(2)*(1-params(5))*(1-params(13))/exp(y(48));
T757 = (-(exp(y(14))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T946 = (-(params(2)*exp(y(89))*exp(y(48))))/(exp(y(48))*exp(y(48)));
T951 = (-(exp(y(89))*exp(y(48))))/(exp(y(48))*exp(y(48)));
lhs =y(46);
rhs =log(exp(y(9)));
residual(1)= lhs-rhs;
lhs =y(47);
rhs =y(46)+params(2)*y(88);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(44)))+(1-params(5))*(1-exp(y(21)))*exp(y(7))+(1-params(5))*(1-exp(y(21)))*exp(y(3))*exp(y(6));
residual(4) = (-params(17))/exp(y(16))+(1-params(5))*(1-params(13))*T53*((1-exp(y(80)))*exp(y(81))-exp(y(80))*y(63));
residual(5) = (-exp(y(50)))+exp(y(28))-params(17)/exp(y(16))-y(63);
residual(6) = (-exp(y(25)))+(1-params(6))/params(6)*exp(y(26));
residual(7) = (-exp(y(28)))+exp(y(12))-params(6)*(exp(y(22))-exp(y(50)));
residual(8) = (-exp(y(42)))+T112*T116;
residual(9) = (-exp(y(35)))+exp(y(38))*exp(y(41))-exp(y(44))*exp(y(12))-params(17)*exp(y(43))-exp(y(23))*exp(y(45))-y(63)*exp(y(44))*exp(y(21))/(1-exp(y(21)));
residual(10) = (-exp(y(34)))+params(18)+y(64)+params(17)*(exp(y(43))+exp(y(44))/exp(y(16)));
residual(11) = (-exp(y(41)))+exp(y(42))/exp(y(36));
residual(12) = (-exp(y(38)))+exp(y(40))*exp(y(31));
residual(13) = (-exp(y(34)))+T174*(exp(y(86))+exp(y(87)));
residual(14) = (-exp(y(36)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(15) = (-1)+exp(y(38))*T200;
residual(16) = (-exp(y(40)))+exp(y(39))/(exp(y(39))-1);
residual(17) = (-exp(y(39)))+1+exp(y(36))*params(15);
residual(18) = (-exp(y(41)))+T220;
residual(19) = (-exp(y(29)))+exp(y(52))+exp(y(14))+params(17)*exp(y(11))+(params(18)+y(64))*exp(y(37))+T240;
residual(20) = (-exp(y(13)))+exp(y(1))*(1-params(19))+exp(y(14))*T255;
residual(21) = (-exp(y(32)))+T53*(exp(y(83))+(1-params(19))*exp(y(84)));
residual(22) = (-1)+T277+T287;
residual(23) = T274-y(33)-1;
residual(24) = (1-params(5))*(1-params(13))*T53*((1-exp(y(80)))*exp(y(81))-exp(y(80))*y(90))+exp(y(22))-exp(y(24))-exp(y(12));
residual(25) = (1-params(5))*(1-params(13))*T53*(1-exp(y(80)))*exp(y(82))+exp(y(12))-exp(y(26))-exp(y(27));
residual(26) = (-exp(y(27)))+params(23)+exp(y(62))+T328;
residual(27) = (-exp(y(11)))+exp(y(43))*(exp(y(36))+exp(y(37)))+T336;
residual(28) = (-exp(y(44)))+exp(y(10))/exp(y(36));
residual(29) = (-exp(y(45)))+exp(y(1))/exp(y(36));
residual(30) = (-exp(y(17)))+params(16)*exp(y(11))^(1-params(7))*exp(y(19))^params(7);
residual(31) = 1-exp(y(19))-exp(y(10));
residual(32) = (-exp(y(18)))+exp(y(17))/exp(y(19));
residual(33) = (-exp(y(16)))+exp(y(17))/exp(y(11));
residual(34) = (-exp(y(49)))+T432/(1-exp(y(21)));
residual(35) = (-exp(y(20)))+exp(y(49))^((1-params(10))/params(20));
residual(36) = (-exp(y(21)))+0.5+0.5*erf(log(exp(y(15)))/(params(9)*1.414213562373095));
residual(37) = (-exp(y(22)))+T452;
residual(38) = (-exp(y(50)))+exp(y(22))*T455^params(21);
residual(39) = (-exp(y(23)))+T464;
residual(40) = y(63)+(-exp(y(25)))+exp(y(24));
residual(41) = exp(y(23))-exp(y(30));
residual(42) = exp(y(9))-exp(y(52))-params(23)*(1-exp(y(10)));
residual(43) = (-exp(y(48)))+exp(y(9))^(-params(1));
residual(44) = (-y(54))+params(3)*y(8)-x(it_, 1);
residual(45) = (-exp(y(62)))+params(24)*params(102)/params(103)+params(25)*(log(exp(y(56)))-log(params(105)));
residual(46) = (-y(63))+params(71);
residual(47) = (-y(64))+params(72);
residual(48) = (1-exp(y(21)))*(1-params(5))*params(13)+(1-params(5))*exp(y(21))+params(5)-exp(y(51));
residual(49) = (-exp(y(55)))+exp(y(12))*exp(y(10))+exp(y(1))*exp(y(30))+exp(y(35))*exp(y(36));
residual(50) = (params(18)+y(64))*exp(y(37))-exp(y(53));
residual(51) = (-exp(y(56)))+exp(y(55))/exp(y(38));
residual(52) = (-exp(y(57)))+exp(y(52))/exp(y(38));
residual(53) = (-exp(y(58)))+exp(y(14))/exp(y(38));
residual(54) = (-exp(y(60)))+exp(y(12))/exp(y(38));
residual(55) = (-exp(y(61)))+exp(y(9))/exp(y(38));
residual(56) = (-exp(y(59)))+exp(y(53))/exp(y(38));
residual(57) = (-exp(y(65)))+exp(y(11))/exp(y(19));
residual(58) = T590*(params(17)*exp(y(65))+T595)+exp(y(62))+params(23)-exp(y(66));
residual(59) = (-exp(y(67)))+y(63)*params(6)*(1-params(2)*(1-params(5))*(1-params(13))*(1-exp(y(18))));
residual(60) = (-exp(y(68)))+exp(y(44))*(1-params(5))*exp(y(21));
residual(61) = (-exp(y(69)))+exp(y(44))*params(5);
residual(62) = (-exp(y(70)))+exp(y(10))*(1-params(5))*exp(y(21));
residual(63) = (-exp(y(71)))+params(5)*exp(y(10));
residual(64) = (-exp(y(72)))+exp(y(16))*exp(y(43));
residual(65) = (-exp(y(73)))+exp(y(16))*exp(y(11));
residual(66) = (1-params(5))*exp(y(21))+params(5)-exp(y(74));
residual(67) = 1-exp(y(75))-(1-params(13))*(1-exp(y(74)));
residual(68) = (-exp(y(76)))+exp(y(10))*exp(y(75))-exp(y(16))*params(5)*exp(y(10));
residual(69) = exp(y(16))*exp(y(11))-exp(y(77))-exp(y(16))*params(5)*exp(y(10));
residual(70) = exp(y(77))-exp(y(78))-exp(y(76));
if nargout >= 2,
  g1 = zeros(70, 91);

  %
  % Jacobian matrix
  %

  g1(1,9)=(-1);
  g1(1,46)=1;
  g1(2,46)=(-1);
  g1(2,47)=1;
  g1(2,88)=(-params(2));
  g1(3,3)=(1-params(5))*(1-exp(y(21)))*exp(y(3))*exp(y(6));
  g1(3,21)=exp(y(7))*(1-params(5))*(-exp(y(21)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(21)));
  g1(3,6)=(1-params(5))*(1-exp(y(21)))*exp(y(3))*exp(y(6));
  g1(3,7)=(1-params(5))*(1-exp(y(21)))*exp(y(7));
  g1(3,44)=(-exp(y(44)));
  g1(4,16)=(-((-params(17))*exp(y(16))))/(exp(y(16))*exp(y(16)));
  g1(4,80)=(1-params(5))*(1-params(13))*T53*(exp(y(81))*(-exp(y(80)))-exp(y(80))*y(63));
  g1(4,81)=(1-params(5))*(1-params(13))*T53*(1-exp(y(80)))*exp(y(81));
  g1(4,48)=((1-exp(y(80)))*exp(y(81))-exp(y(80))*y(63))*(1-params(5))*(1-params(13))*T946;
  g1(4,89)=(1-params(5))*(1-params(13))*T53*((1-exp(y(80)))*exp(y(81))-exp(y(80))*y(63));
  g1(4,63)=(1-params(5))*(1-params(13))*T53*(-exp(y(80)));
  g1(5,16)=(-((-(params(17)*exp(y(16))))/(exp(y(16))*exp(y(16)))));
  g1(5,28)=exp(y(28));
  g1(5,50)=(-exp(y(50)));
  g1(5,63)=(-1);
  g1(6,25)=(-exp(y(25)));
  g1(6,26)=(1-params(6))/params(6)*exp(y(26));
  g1(7,12)=exp(y(12));
  g1(7,22)=(-(params(6)*exp(y(22))));
  g1(7,28)=(-exp(y(28)));
  g1(7,50)=(-((-exp(y(50)))*params(6)));
  g1(8,10)=T112*exp(y(10))*getPowerDeriv(exp(y(10)),1-params(10),1);
  g1(8,1)=T116*exp(y(54))*exp(y(20))^params(20)*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
  g1(8,20)=T116*exp(y(1))^params(10)*exp(y(54))*exp(y(20))*getPowerDeriv(exp(y(20)),params(20),1);
  g1(8,42)=(-exp(y(42)));
  g1(8,54)=T112*T116;
  g1(9,12)=(-(exp(y(44))*exp(y(12))));
  g1(9,21)=(-(((1-exp(y(21)))*y(63)*exp(y(44))*exp(y(21))-y(63)*exp(y(44))*exp(y(21))*(-exp(y(21))))/((1-exp(y(21)))*(1-exp(y(21))))));
  g1(9,23)=(-(exp(y(23))*exp(y(45))));
  g1(9,35)=(-exp(y(35)));
  g1(9,38)=exp(y(38))*exp(y(41));
  g1(9,41)=exp(y(38))*exp(y(41));
  g1(9,43)=(-(params(17)*exp(y(43))));
  g1(9,44)=(-(exp(y(44))*exp(y(12))))-y(63)*exp(y(44))*exp(y(21))/(1-exp(y(21)));
  g1(9,45)=(-(exp(y(23))*exp(y(45))));
  g1(9,63)=(-(exp(y(44))*exp(y(21))/(1-exp(y(21)))));
  g1(10,16)=params(17)*(-(exp(y(44))*exp(y(16))))/(exp(y(16))*exp(y(16)));
  g1(10,34)=(-exp(y(34)));
  g1(10,43)=params(17)*exp(y(43));
  g1(10,44)=params(17)*exp(y(44))/exp(y(16));
  g1(10,64)=1;
  g1(11,36)=(-(exp(y(42))*exp(y(36))))/(exp(y(36))*exp(y(36)));
  g1(11,41)=(-exp(y(41)));
  g1(11,42)=exp(y(42))/exp(y(36));
  g1(12,31)=exp(y(40))*exp(y(31));
  g1(12,38)=(-exp(y(38)));
  g1(12,40)=exp(y(40))*exp(y(31));
  g1(13,34)=(-exp(y(34)));
  g1(13,86)=T174*exp(y(86));
  g1(13,87)=T174*exp(y(87));
  g1(13,48)=(exp(y(86))+exp(y(87)))*params(2)*(1-params(13))*T951;
  g1(13,89)=T174*(exp(y(86))+exp(y(87)));
  g1(14,4)=(1-params(13))*exp(y(4));
  g1(14,36)=(-exp(y(36)));
  g1(14,5)=(1-params(13))*exp(y(5));
  g1(15,36)=exp(y(38))*T200*(exp(y(36))*params(14)*params(15)*(-exp(y(36)))*.5-.5*(params(14)-exp(y(36)))*exp(y(36))*params(14)*params(15))/(exp(y(36))*params(14)*params(15)*exp(y(36))*params(14)*params(15));
  g1(15,38)=exp(y(38))*T200;
  g1(16,39)=(exp(y(39))*(exp(y(39))-1)-exp(y(39))*exp(y(39)))/((exp(y(39))-1)*(exp(y(39))-1));
  g1(16,40)=(-exp(y(40)));
  g1(17,36)=exp(y(36))*params(15);
  g1(17,39)=(-exp(y(39)));
  g1(18,29)=T220;
  g1(18,36)=(-(exp(y(36))*1/exp(y(38))*exp(y(29))))/(exp(y(36))*exp(y(36)));
  g1(18,38)=exp(y(29))*(-exp(y(38)))/(exp(y(38))*exp(y(38)))/exp(y(36));
  g1(18,41)=(-exp(y(41)));
  g1(19,11)=params(17)*exp(y(11));
  g1(19,14)=exp(y(14));
  g1(19,21)=((1-exp(y(21)))*y(63)*exp(y(44))*exp(y(21))*exp(y(36))-y(63)*exp(y(44))*exp(y(21))*exp(y(36))*(-exp(y(21))))/((1-exp(y(21)))*(1-exp(y(21))));
  g1(19,29)=(-exp(y(29)));
  g1(19,36)=T240;
  g1(19,37)=(params(18)+y(64))*exp(y(37));
  g1(19,44)=T240;
  g1(19,52)=exp(y(52));
  g1(19,63)=exp(y(44))*exp(y(21))*exp(y(36))/(1-exp(y(21)));
  g1(19,64)=exp(y(37));
  g1(20,1)=exp(y(1))*(1-params(19));
  g1(20,13)=(-exp(y(13)));
  g1(20,14)=exp(y(14))*T255;
  g1(20,33)=exp(y(14))*(-(params(12)/2*2*y(33)));
  g1(21,83)=T53*exp(y(83));
  g1(21,32)=(-exp(y(32)));
  g1(21,84)=T53*(1-params(19))*exp(y(84));
  g1(21,48)=(exp(y(83))+(1-params(19))*exp(y(84)))*T946;
  g1(21,89)=T53*(exp(y(83))+(1-params(19))*exp(y(84)));
  g1(22,2)=exp(y(32))*(-(params(12)*y(33)*T757));
  g1(22,14)=exp(y(32))*(-(params(12)*y(33)*T274))+exp(y(84))*T53*params(12)*y(85)*(-(exp(y(14))*exp(y(79))))/(exp(y(14))*exp(y(14)))*2*T284;
  g1(22,79)=exp(y(84))*T53*params(12)*y(85)*T284*2*T284;
  g1(22,32)=T277;
  g1(22,84)=T287;
  g1(22,33)=exp(y(32))*((-(params(12)/2*2*y(33)))-params(12)*T274);
  g1(22,85)=exp(y(84))*T53*params(12)*T284^2;
  g1(22,48)=y(85)*T284^2*exp(y(84))*params(12)*T946;
  g1(22,89)=T287;
  g1(23,2)=T757;
  g1(23,14)=T274;
  g1(23,33)=(-1);
  g1(24,12)=(-exp(y(12)));
  g1(24,80)=(1-params(5))*(1-params(13))*T53*(exp(y(81))*(-exp(y(80)))-exp(y(80))*y(90));
  g1(24,22)=exp(y(22));
  g1(24,24)=(-exp(y(24)));
  g1(24,81)=(1-params(5))*(1-params(13))*T53*(1-exp(y(80)))*exp(y(81));
  g1(24,48)=((1-exp(y(80)))*exp(y(81))-exp(y(80))*y(90))*(1-params(5))*(1-params(13))*T946;
  g1(24,89)=(1-params(5))*(1-params(13))*T53*((1-exp(y(80)))*exp(y(81))-exp(y(80))*y(90));
  g1(24,90)=(1-params(5))*(1-params(13))*T53*(-exp(y(80)));
  g1(25,12)=exp(y(12));
  g1(25,80)=exp(y(82))*(1-params(5))*(1-params(13))*T53*(-exp(y(80)));
  g1(25,26)=(-exp(y(26)));
  g1(25,82)=(1-params(5))*(1-params(13))*T53*(1-exp(y(80)))*exp(y(82));
  g1(25,27)=(-exp(y(27)));
  g1(25,48)=exp(y(82))*(1-exp(y(80)))*(1-params(5))*(1-params(13))*T946;
  g1(25,89)=(1-params(5))*(1-params(13))*T53*(1-exp(y(80)))*exp(y(82));
  g1(26,18)=T328;
  g1(26,80)=exp(y(82))*T326*(-exp(y(80)));
  g1(26,82)=T328;
  g1(26,27)=(-exp(y(27)));
  g1(26,48)=exp(y(82))*(1-exp(y(80)))*exp(y(18))*params(2)*(1-params(5))*(1-params(13))*T951;
  g1(26,89)=T328;
  g1(26,62)=exp(y(62));
  g1(27,11)=(-exp(y(11)));
  g1(27,16)=(-(exp(y(16))*exp(y(44))*exp(y(37))))/(exp(y(16))*exp(y(16)));
  g1(27,36)=exp(y(43))*exp(y(36));
  g1(27,37)=T336+exp(y(43))*exp(y(37));
  g1(27,43)=exp(y(43))*(exp(y(36))+exp(y(37)));
  g1(27,44)=T336;
  g1(28,10)=exp(y(10))/exp(y(36));
  g1(28,36)=(-(exp(y(10))*exp(y(36))))/(exp(y(36))*exp(y(36)));
  g1(28,44)=(-exp(y(44)));
  g1(29,1)=exp(y(1))/exp(y(36));
  g1(29,36)=(-(exp(y(1))*exp(y(36))))/(exp(y(36))*exp(y(36)));
  g1(29,45)=(-exp(y(45)));
  g1(30,11)=exp(y(19))^params(7)*params(16)*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(7),1);
  g1(30,17)=(-exp(y(17)));
  g1(30,19)=params(16)*exp(y(11))^(1-params(7))*exp(y(19))*getPowerDeriv(exp(y(19)),params(7),1);
  g1(31,10)=(-exp(y(10)));
  g1(31,19)=(-exp(y(19)));
  g1(32,17)=exp(y(17))/exp(y(19));
  g1(32,18)=(-exp(y(18)));
  g1(32,19)=(-(exp(y(17))*exp(y(19))))/(exp(y(19))*exp(y(19)));
  g1(33,11)=(-(exp(y(11))*exp(y(17))))/(exp(y(11))*exp(y(11)));
  g1(33,16)=(-exp(y(16)));
  g1(33,17)=exp(y(17))/exp(y(11));
  g1(34,15)=T430*T394*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T410^2)*1.772453850905516)/params(11)^0.5/(1-exp(y(21)));
  g1(34,21)=(-(T432*(-exp(y(21)))))/((1-exp(y(21)))*(1-exp(y(21))));
  g1(34,49)=(-exp(y(49)));
  g1(35,20)=(-exp(y(20)));
  g1(35,49)=exp(y(49))*getPowerDeriv(exp(y(49)),(1-params(10))/params(20),1);
  g1(36,15)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(15)))/(params(9)*1.414213562373095))^2));
  g1(36,21)=(-exp(y(21)));
  g1(37,10)=(-(exp(y(10))*exp(y(42))*(1-params(10))*exp(y(31))))/(exp(y(10))*exp(y(10)));
  g1(37,22)=(-exp(y(22)));
  g1(37,31)=T452;
  g1(37,42)=T452;
  g1(38,15)=exp(y(22))*T455*getPowerDeriv(T455,params(21),1);
  g1(38,20)=exp(y(22))*getPowerDeriv(T455,params(21),1)*(-(exp(y(20))*exp(y(15))))/(exp(y(20))*exp(y(20)));
  g1(38,22)=exp(y(22))*T455^params(21);
  g1(38,50)=(-exp(y(50)));
  g1(39,1)=(-(exp(y(1))*exp(y(42))*params(10)*exp(y(31))))/(exp(y(1))*exp(y(1)));
  g1(39,23)=(-exp(y(23)));
  g1(39,31)=T464;
  g1(39,42)=T464;
  g1(40,24)=exp(y(24));
  g1(40,25)=(-exp(y(25)));
  g1(40,63)=1;
  g1(41,23)=exp(y(23));
  g1(41,30)=(-exp(y(30)));
  g1(42,9)=exp(y(9));
  g1(42,10)=(-(params(23)*(-exp(y(10)))));
  g1(42,52)=(-exp(y(52)));
  g1(43,9)=exp(y(9))*getPowerDeriv(exp(y(9)),(-params(1)),1);
  g1(43,48)=(-exp(y(48)));
  g1(44,8)=params(3);
  g1(44,54)=(-1);
  g1(44,91)=(-1);
  g1(45,56)=params(25);
  g1(45,62)=(-exp(y(62)));
  g1(46,63)=(-1);
  g1(47,64)=(-1);
  g1(48,21)=(1-params(5))*exp(y(21))+(-exp(y(21)))*(1-params(5))*params(13);
  g1(48,51)=(-exp(y(51)));
  g1(49,10)=exp(y(12))*exp(y(10));
  g1(49,12)=exp(y(12))*exp(y(10));
  g1(49,1)=exp(y(1))*exp(y(30));
  g1(49,30)=exp(y(1))*exp(y(30));
  g1(49,35)=exp(y(35))*exp(y(36));
  g1(49,36)=exp(y(35))*exp(y(36));
  g1(49,55)=(-exp(y(55)));
  g1(50,37)=(params(18)+y(64))*exp(y(37));
  g1(50,53)=(-exp(y(53)));
  g1(50,64)=exp(y(37));
  g1(51,38)=(-(exp(y(38))*exp(y(55))))/(exp(y(38))*exp(y(38)));
  g1(51,55)=exp(y(55))/exp(y(38));
  g1(51,56)=(-exp(y(56)));
  g1(52,38)=(-(exp(y(38))*exp(y(52))))/(exp(y(38))*exp(y(38)));
  g1(52,52)=exp(y(52))/exp(y(38));
  g1(52,57)=(-exp(y(57)));
  g1(53,14)=exp(y(14))/exp(y(38));
  g1(53,38)=(-(exp(y(38))*exp(y(14))))/(exp(y(38))*exp(y(38)));
  g1(53,58)=(-exp(y(58)));
  g1(54,12)=exp(y(12))/exp(y(38));
  g1(54,38)=(-(exp(y(12))*exp(y(38))))/(exp(y(38))*exp(y(38)));
  g1(54,60)=(-exp(y(60)));
  g1(55,9)=exp(y(9))/exp(y(38));
  g1(55,38)=(-(exp(y(9))*exp(y(38))))/(exp(y(38))*exp(y(38)));
  g1(55,61)=(-exp(y(61)));
  g1(56,38)=(-(exp(y(38))*exp(y(53))))/(exp(y(38))*exp(y(38)));
  g1(56,53)=exp(y(53))/exp(y(38));
  g1(56,59)=(-exp(y(59)));
  g1(57,11)=exp(y(11))/exp(y(19));
  g1(57,19)=(-(exp(y(11))*exp(y(19))))/(exp(y(19))*exp(y(19)));
  g1(57,65)=(-exp(y(65)));
  g1(58,18)=T590*T595;
  g1(58,48)=T590*exp(y(18))*y(63)*(-(exp(y(48))*exp(y(89))*params(2)*(1-params(5))*(1-params(13))))/(exp(y(48))*exp(y(48)));
  g1(58,89)=T590*T595;
  g1(58,62)=exp(y(62));
  g1(58,63)=T590*exp(y(18))*exp(y(89))*params(2)*(1-params(5))*(1-params(13))/exp(y(48));
  g1(58,65)=T590*params(17)*exp(y(65));
  g1(58,66)=(-exp(y(66)));
  g1(59,18)=y(63)*params(6)*(-(params(2)*(1-params(5))*(1-params(13))*(-exp(y(18)))));
  g1(59,63)=params(6)*(1-params(2)*(1-params(5))*(1-params(13))*(1-exp(y(18))));
  g1(59,67)=(-exp(y(67)));
  g1(60,21)=exp(y(44))*(1-params(5))*exp(y(21));
  g1(60,44)=exp(y(44))*(1-params(5))*exp(y(21));
  g1(60,68)=(-exp(y(68)));
  g1(61,44)=exp(y(44))*params(5);
  g1(61,69)=(-exp(y(69)));
  g1(62,10)=exp(y(10))*(1-params(5))*exp(y(21));
  g1(62,21)=exp(y(10))*(1-params(5))*exp(y(21));
  g1(62,70)=(-exp(y(70)));
  g1(63,10)=params(5)*exp(y(10));
  g1(63,71)=(-exp(y(71)));
  g1(64,16)=exp(y(16))*exp(y(43));
  g1(64,43)=exp(y(16))*exp(y(43));
  g1(64,72)=(-exp(y(72)));
  g1(65,11)=exp(y(16))*exp(y(11));
  g1(65,16)=exp(y(16))*exp(y(11));
  g1(65,73)=(-exp(y(73)));
  g1(66,21)=(1-params(5))*exp(y(21));
  g1(66,74)=(-exp(y(74)));
  g1(67,74)=(-((1-params(13))*(-exp(y(74)))));
  g1(67,75)=(-exp(y(75)));
  g1(68,10)=exp(y(10))*exp(y(75))-exp(y(16))*params(5)*exp(y(10));
  g1(68,16)=(-(exp(y(16))*params(5)*exp(y(10))));
  g1(68,75)=exp(y(10))*exp(y(75));
  g1(68,76)=(-exp(y(76)));
  g1(69,10)=(-(exp(y(16))*params(5)*exp(y(10))));
  g1(69,11)=exp(y(16))*exp(y(11));
  g1(69,16)=exp(y(16))*exp(y(11))-exp(y(16))*params(5)*exp(y(10));
  g1(69,77)=(-exp(y(77)));
  g1(70,76)=(-exp(y(76)));
  g1(70,77)=exp(y(77));
  g1(70,78)=(-exp(y(78)));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],70,8281);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],70,753571);
end
end
