function [residual, g1, g2] = cycle_irf_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                     columns: variables in declaration order
%                                                     rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 70, 1);

%
% Model equations
%

T25 = 1-exp(y(13));
T46 = params(2)*exp(y(40))/exp(y(40));
T102 = exp(y(46))*exp(y(12))^params(20)*exp(y(5))^params(10);
T106 = exp(y(2))^(1-params(10));
T180 = exp(.5*(params(14)-exp(y(28)))/(exp(y(28))*params(14)*params(15)));
T200 = 1/exp(y(30))*exp(y(21))/exp(y(28));
T218 = y(55)*exp(y(36))*exp(y(13))*exp(y(28))/T25;
T231 = 1-params(12)/2*y(25)^2;
T287 = exp(y(36))*exp(y(29))/exp(y(8));
T334 = params(20)*params(9)^2;
T344 = (-0.5)*params(11)^0.5*exp(params(20)*0.5*(2*params(8)+T334)/(1-2*params(10)+params(10)^2));
T359 = 0.7071067811865475/params(9)*(params(8)+T334+(-log(exp(y(7))))+params(10)*log(exp(y(7)))-params(10)*params(8))/((-1)+params(10));
T379 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T381 = T344*(erf(T359)-erf(0.7071067811865475*(params(8)+T334+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T379/params(11)^0.5;
T402 = exp(y(34))*(1-params(10))*exp(y(23))/exp(y(2));
T405 = exp(y(7))/exp(y(12));
T414 = exp(y(34))*params(10)*exp(y(23))/exp(y(5));
T528 = params(6)/(1-params(6));
T533 = exp(y(10))*y(55)*exp(y(40))*params(2)*(1-params(5))*(1-params(13))/exp(y(40));
lhs =y(38);
rhs =log(exp(y(1)));
residual(1)= lhs-rhs;
lhs =y(39);
rhs =y(38)+y(39)*params(2);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(36)))+exp(y(36))*(1-params(5))*T25+(1-params(5))*T25*exp(y(8))*exp(y(35));
residual(4) = (-params(17))/exp(y(8))+(1-params(5))*(1-params(13))*T46*(T25*exp(y(16))-exp(y(13))*y(55));
residual(5) = (-exp(y(42)))+exp(y(20))-params(17)/exp(y(8))-y(55);
residual(6) = (-exp(y(17)))+(1-params(6))/params(6)*exp(y(18));
residual(7) = (-exp(y(20)))+exp(y(4))-params(6)*(exp(y(14))-exp(y(42)));
residual(8) = (-exp(y(34)))+T102*T106;
residual(9) = (-exp(y(27)))+exp(y(30))*exp(y(33))-exp(y(36))*exp(y(4))-exp(y(35))*params(17)-exp(y(15))*exp(y(37))-y(55)*exp(y(36))*exp(y(13))/T25;
residual(10) = (-exp(y(26)))+params(18)+y(56)+params(17)*(exp(y(35))+exp(y(36))/exp(y(8)));
residual(11) = (-exp(y(33)))+exp(y(34))/exp(y(28));
residual(12) = (-exp(y(30)))+exp(y(32))*exp(y(23));
residual(13) = (-exp(y(26)))+params(2)*(1-params(13))*(exp(y(27))+exp(y(26)));
residual(14) = (-exp(y(28)))+(1-params(13))*(exp(y(28))+exp(y(29)));
residual(15) = (-1)+exp(y(30))*T180;
residual(16) = (-exp(y(32)))+exp(y(31))/(exp(y(31))-1);
residual(17) = (-exp(y(31)))+1+exp(y(28))*params(15);
residual(18) = (-exp(y(33)))+T200;
residual(19) = (-exp(y(21)))+exp(y(44))+exp(y(6))+params(17)*exp(y(3))+(params(18)+y(56))*exp(y(29))+T218;
residual(20) = (-exp(y(5)))+exp(y(5))*(1-params(19))+exp(y(6))*T231;
residual(21) = (-exp(y(24)))+T46*(exp(y(22))+(1-params(19))*exp(y(24)));
residual(22) = (-1)+exp(y(24))*(T231-params(12)*y(25))+y(25)*exp(y(24))*T46*params(12);
residual(23) = 1-y(25)-1;
residual(24) = (1-params(5))*(1-params(13))*T46*(T25*exp(y(16))-exp(y(13))*y(55))+exp(y(14))-exp(y(16))-exp(y(4));
residual(25) = exp(y(18))*T25*(1-params(5))*(1-params(13))*T46+exp(y(4))-exp(y(18))-exp(y(19));
residual(26) = (-exp(y(19)))+params(23)+exp(y(54))+exp(y(18))*T25*params(2)*(1-params(5))*(1-params(13))*exp(y(10));
residual(27) = (-exp(y(3)))+exp(y(35))*(exp(y(28))+exp(y(29)))+T287;
residual(28) = (-exp(y(36)))+exp(y(2))/exp(y(28));
residual(29) = (-exp(y(37)))+exp(y(5))/exp(y(28));
residual(30) = (-exp(y(9)))+params(16)*exp(y(3))^(1-params(7))*exp(y(11))^params(7);
residual(31) = 1-exp(y(11))-exp(y(2));
residual(32) = (-exp(y(10)))+exp(y(9))/exp(y(11));
residual(33) = (-exp(y(8)))+exp(y(9))/exp(y(3));
residual(34) = (-exp(y(41)))+T381/T25;
residual(35) = (-exp(y(12)))+exp(y(41))^((1-params(10))/params(20));
residual(36) = (-exp(y(13)))+0.5+0.5*erf(log(exp(y(7)))/(params(9)*1.414213562373095));
residual(37) = (-exp(y(14)))+T402;
residual(38) = (-exp(y(42)))+exp(y(14))*T405^params(21);
residual(39) = (-exp(y(15)))+T414;
residual(40) = y(55)+exp(y(16))+(-exp(y(17)));
residual(41) = exp(y(15))-exp(y(22));
residual(42) = exp(y(1))-exp(y(44))-params(23)*(1-exp(y(2)));
residual(43) = (-exp(y(40)))+exp(y(1))^(-params(1));
residual(44) = (-y(46))+y(46)*params(3)-x(1);
residual(45) = (-exp(y(54)))+params(24)*params(102)/params(103)+params(25)*(log(exp(y(48)))-log(params(105)));
residual(46) = (-y(55))+params(71);
residual(47) = (-y(56))+params(72);
residual(48) = T25*(1-params(5))*params(13)+(1-params(5))*exp(y(13))+params(5)-exp(y(43));
residual(49) = (-exp(y(47)))+exp(y(4))*exp(y(2))+exp(y(5))*exp(y(22))+exp(y(27))*exp(y(28));
residual(50) = (params(18)+y(56))*exp(y(29))-exp(y(45));
residual(51) = (-exp(y(48)))+exp(y(47))/exp(y(30));
residual(52) = (-exp(y(49)))+exp(y(44))/exp(y(30));
residual(53) = (-exp(y(50)))+exp(y(6))/exp(y(30));
residual(54) = (-exp(y(52)))+exp(y(4))/exp(y(30));
residual(55) = (-exp(y(53)))+exp(y(1))/exp(y(30));
residual(56) = (-exp(y(51)))+exp(y(45))/exp(y(30));
residual(57) = (-exp(y(57)))+exp(y(3))/exp(y(11));
residual(58) = T528*(params(17)*exp(y(57))+T533)+exp(y(54))+params(23)-exp(y(58));
residual(59) = (-exp(y(59)))+y(55)*params(6)*(1-params(2)*(1-params(5))*(1-params(13))*(1-exp(y(10))));
residual(60) = (-exp(y(60)))+exp(y(36))*(1-params(5))*exp(y(13));
residual(61) = (-exp(y(61)))+exp(y(36))*params(5);
residual(62) = (-exp(y(62)))+exp(y(2))*(1-params(5))*exp(y(13));
residual(63) = (-exp(y(63)))+params(5)*exp(y(2));
residual(64) = (-exp(y(64)))+exp(y(8))*exp(y(35));
residual(65) = (-exp(y(65)))+exp(y(8))*exp(y(3));
residual(66) = (1-params(5))*exp(y(13))+params(5)-exp(y(66));
residual(67) = 1-exp(y(67))-(1-params(13))*(1-exp(y(66)));
residual(68) = (-exp(y(68)))+exp(y(2))*exp(y(67))-exp(y(8))*params(5)*exp(y(2));
residual(69) = exp(y(8))*exp(y(3))-exp(y(69))-exp(y(8))*params(5)*exp(y(2));
residual(70) = exp(y(69))-exp(y(70))-exp(y(68));
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(70, 70);

  %
  % Jacobian matrix
  %

  g1(1,1)=(-1);
  g1(1,38)=1;
  g1(2,38)=(-1);
  g1(2,39)=1-params(2);
  g1(3,8)=(1-params(5))*T25*exp(y(8))*exp(y(35));
  g1(3,13)=exp(y(36))*(1-params(5))*(-exp(y(13)))+exp(y(35))*exp(y(8))*(1-params(5))*(-exp(y(13)));
  g1(3,35)=(1-params(5))*T25*exp(y(8))*exp(y(35));
  g1(3,36)=(-exp(y(36)))+exp(y(36))*(1-params(5))*T25;
  g1(4,8)=(-(exp(y(8))*(-params(17))))/(exp(y(8))*exp(y(8)));
  g1(4,13)=(1-params(5))*(1-params(13))*T46*(exp(y(16))*(-exp(y(13)))-exp(y(13))*y(55));
  g1(4,16)=(1-params(5))*(1-params(13))*T46*T25*exp(y(16));
  g1(4,55)=(1-params(5))*(1-params(13))*T46*(-exp(y(13)));
  g1(5,8)=(-((-(exp(y(8))*params(17)))/(exp(y(8))*exp(y(8)))));
  g1(5,20)=exp(y(20));
  g1(5,42)=(-exp(y(42)));
  g1(5,55)=(-1);
  g1(6,17)=(-exp(y(17)));
  g1(6,18)=(1-params(6))/params(6)*exp(y(18));
  g1(7,4)=exp(y(4));
  g1(7,14)=(-(params(6)*exp(y(14))));
  g1(7,20)=(-exp(y(20)));
  g1(7,42)=(-((-exp(y(42)))*params(6)));
  g1(8,2)=T102*exp(y(2))*getPowerDeriv(exp(y(2)),1-params(10),1);
  g1(8,5)=T106*exp(y(46))*exp(y(12))^params(20)*exp(y(5))*getPowerDeriv(exp(y(5)),params(10),1);
  g1(8,12)=T106*exp(y(5))^params(10)*exp(y(46))*exp(y(12))*getPowerDeriv(exp(y(12)),params(20),1);
  g1(8,34)=(-exp(y(34)));
  g1(8,46)=T102*T106;
  g1(9,4)=(-(exp(y(36))*exp(y(4))));
  g1(9,13)=(-((T25*y(55)*exp(y(36))*exp(y(13))-y(55)*exp(y(36))*exp(y(13))*(-exp(y(13))))/(T25*T25)));
  g1(9,15)=(-(exp(y(15))*exp(y(37))));
  g1(9,27)=(-exp(y(27)));
  g1(9,30)=exp(y(30))*exp(y(33));
  g1(9,33)=exp(y(30))*exp(y(33));
  g1(9,35)=(-(exp(y(35))*params(17)));
  g1(9,36)=(-(exp(y(36))*exp(y(4))))-y(55)*exp(y(36))*exp(y(13))/T25;
  g1(9,37)=(-(exp(y(15))*exp(y(37))));
  g1(9,55)=(-(exp(y(36))*exp(y(13))/T25));
  g1(10,8)=params(17)*(-(exp(y(36))*exp(y(8))))/(exp(y(8))*exp(y(8)));
  g1(10,26)=(-exp(y(26)));
  g1(10,35)=exp(y(35))*params(17);
  g1(10,36)=params(17)*exp(y(36))/exp(y(8));
  g1(10,56)=1;
  g1(11,28)=(-(exp(y(34))*exp(y(28))))/(exp(y(28))*exp(y(28)));
  g1(11,33)=(-exp(y(33)));
  g1(11,34)=exp(y(34))/exp(y(28));
  g1(12,23)=exp(y(32))*exp(y(23));
  g1(12,30)=(-exp(y(30)));
  g1(12,32)=exp(y(32))*exp(y(23));
  g1(13,26)=(-exp(y(26)))+exp(y(26))*params(2)*(1-params(13));
  g1(13,27)=exp(y(27))*params(2)*(1-params(13));
  g1(14,28)=(-exp(y(28)))+(1-params(13))*exp(y(28));
  g1(14,29)=(1-params(13))*exp(y(29));
  g1(15,28)=exp(y(30))*T180*(exp(y(28))*params(14)*params(15)*(-exp(y(28)))*.5-.5*(params(14)-exp(y(28)))*exp(y(28))*params(14)*params(15))/(exp(y(28))*params(14)*params(15)*exp(y(28))*params(14)*params(15));
  g1(15,30)=exp(y(30))*T180;
  g1(16,31)=(exp(y(31))*(exp(y(31))-1)-exp(y(31))*exp(y(31)))/((exp(y(31))-1)*(exp(y(31))-1));
  g1(16,32)=(-exp(y(32)));
  g1(17,28)=exp(y(28))*params(15);
  g1(17,31)=(-exp(y(31)));
  g1(18,21)=T200;
  g1(18,28)=(-(exp(y(28))*1/exp(y(30))*exp(y(21))))/(exp(y(28))*exp(y(28)));
  g1(18,30)=exp(y(21))*(-exp(y(30)))/(exp(y(30))*exp(y(30)))/exp(y(28));
  g1(18,33)=(-exp(y(33)));
  g1(19,3)=params(17)*exp(y(3));
  g1(19,6)=exp(y(6));
  g1(19,13)=(T25*y(55)*exp(y(36))*exp(y(13))*exp(y(28))-y(55)*exp(y(36))*exp(y(13))*exp(y(28))*(-exp(y(13))))/(T25*T25);
  g1(19,21)=(-exp(y(21)));
  g1(19,28)=T218;
  g1(19,29)=(params(18)+y(56))*exp(y(29));
  g1(19,36)=T218;
  g1(19,44)=exp(y(44));
  g1(19,55)=exp(y(36))*exp(y(13))*exp(y(28))/T25;
  g1(19,56)=exp(y(29));
  g1(20,5)=(-exp(y(5)))+exp(y(5))*(1-params(19));
  g1(20,6)=exp(y(6))*T231;
  g1(20,25)=exp(y(6))*(-(params(12)/2*2*y(25)));
  g1(21,22)=T46*exp(y(22));
  g1(21,24)=(-exp(y(24)))+T46*(1-params(19))*exp(y(24));
  g1(22,24)=exp(y(24))*(T231-params(12)*y(25))+y(25)*exp(y(24))*T46*params(12);
  g1(22,25)=exp(y(24))*T46*params(12)+exp(y(24))*((-(params(12)/2*2*y(25)))-params(12));
  g1(23,25)=(-1);
  g1(24,4)=(-exp(y(4)));
  g1(24,13)=(1-params(5))*(1-params(13))*T46*(exp(y(16))*(-exp(y(13)))-exp(y(13))*y(55));
  g1(24,14)=exp(y(14));
  g1(24,16)=(1-params(5))*(1-params(13))*T46*T25*exp(y(16))-exp(y(16));
  g1(24,55)=(1-params(5))*(1-params(13))*T46*(-exp(y(13)));
  g1(25,4)=exp(y(4));
  g1(25,13)=exp(y(18))*(1-params(5))*(1-params(13))*T46*(-exp(y(13)));
  g1(25,18)=exp(y(18))*T25*(1-params(5))*(1-params(13))*T46-exp(y(18));
  g1(25,19)=(-exp(y(19)));
  g1(26,10)=exp(y(18))*T25*params(2)*(1-params(5))*(1-params(13))*exp(y(10));
  g1(26,13)=exp(y(18))*params(2)*(1-params(5))*(1-params(13))*exp(y(10))*(-exp(y(13)));
  g1(26,18)=exp(y(18))*T25*params(2)*(1-params(5))*(1-params(13))*exp(y(10));
  g1(26,19)=(-exp(y(19)));
  g1(26,54)=exp(y(54));
  g1(27,3)=(-exp(y(3)));
  g1(27,8)=(-(exp(y(8))*exp(y(36))*exp(y(29))))/(exp(y(8))*exp(y(8)));
  g1(27,28)=exp(y(35))*exp(y(28));
  g1(27,29)=T287+exp(y(35))*exp(y(29));
  g1(27,35)=exp(y(35))*(exp(y(28))+exp(y(29)));
  g1(27,36)=T287;
  g1(28,2)=exp(y(2))/exp(y(28));
  g1(28,28)=(-(exp(y(2))*exp(y(28))))/(exp(y(28))*exp(y(28)));
  g1(28,36)=(-exp(y(36)));
  g1(29,5)=exp(y(5))/exp(y(28));
  g1(29,28)=(-(exp(y(5))*exp(y(28))))/(exp(y(28))*exp(y(28)));
  g1(29,37)=(-exp(y(37)));
  g1(30,3)=exp(y(11))^params(7)*params(16)*exp(y(3))*getPowerDeriv(exp(y(3)),1-params(7),1);
  g1(30,9)=(-exp(y(9)));
  g1(30,11)=params(16)*exp(y(3))^(1-params(7))*exp(y(11))*getPowerDeriv(exp(y(11)),params(7),1);
  g1(31,2)=(-exp(y(2)));
  g1(31,11)=(-exp(y(11)));
  g1(32,9)=exp(y(9))/exp(y(11));
  g1(32,10)=(-exp(y(10)));
  g1(32,11)=(-(exp(y(9))*exp(y(11))))/(exp(y(11))*exp(y(11)));
  g1(33,3)=(-(exp(y(3))*exp(y(9))))/(exp(y(3))*exp(y(3)));
  g1(33,8)=(-exp(y(8)));
  g1(33,9)=exp(y(9))/exp(y(3));
  g1(34,7)=T379*T344*0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10))*2/(exp(T359^2)*1.772453850905516)/params(11)^0.5/T25;
  g1(34,13)=(-(T381*(-exp(y(13)))))/(T25*T25);
  g1(34,41)=(-exp(y(41)));
  g1(35,12)=(-exp(y(12)));
  g1(35,41)=exp(y(41))*getPowerDeriv(exp(y(41)),(1-params(10))/params(20),1);
  g1(36,7)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*exp((log(exp(y(7)))/(params(9)*1.414213562373095))^2));
  g1(36,13)=(-exp(y(13)));
  g1(37,2)=(-(exp(y(2))*exp(y(34))*(1-params(10))*exp(y(23))))/(exp(y(2))*exp(y(2)));
  g1(37,14)=(-exp(y(14)));
  g1(37,23)=T402;
  g1(37,34)=T402;
  g1(38,7)=exp(y(14))*T405*getPowerDeriv(T405,params(21),1);
  g1(38,12)=exp(y(14))*getPowerDeriv(T405,params(21),1)*(-(exp(y(12))*exp(y(7))))/(exp(y(12))*exp(y(12)));
  g1(38,14)=exp(y(14))*T405^params(21);
  g1(38,42)=(-exp(y(42)));
  g1(39,5)=(-(exp(y(5))*exp(y(34))*params(10)*exp(y(23))))/(exp(y(5))*exp(y(5)));
  g1(39,15)=(-exp(y(15)));
  g1(39,23)=T414;
  g1(39,34)=T414;
  g1(40,16)=exp(y(16));
  g1(40,17)=(-exp(y(17)));
  g1(40,55)=1;
  g1(41,15)=exp(y(15));
  g1(41,22)=(-exp(y(22)));
  g1(42,1)=exp(y(1));
  g1(42,2)=(-(params(23)*(-exp(y(2)))));
  g1(42,44)=(-exp(y(44)));
  g1(43,1)=exp(y(1))*getPowerDeriv(exp(y(1)),(-params(1)),1);
  g1(43,40)=(-exp(y(40)));
  g1(44,46)=(-1)+params(3);
  g1(45,48)=params(25);
  g1(45,54)=(-exp(y(54)));
  g1(46,55)=(-1);
  g1(47,56)=(-1);
  g1(48,13)=(1-params(5))*exp(y(13))+(-exp(y(13)))*(1-params(5))*params(13);
  g1(48,43)=(-exp(y(43)));
  g1(49,2)=exp(y(4))*exp(y(2));
  g1(49,4)=exp(y(4))*exp(y(2));
  g1(49,5)=exp(y(5))*exp(y(22));
  g1(49,22)=exp(y(5))*exp(y(22));
  g1(49,27)=exp(y(27))*exp(y(28));
  g1(49,28)=exp(y(27))*exp(y(28));
  g1(49,47)=(-exp(y(47)));
  g1(50,29)=(params(18)+y(56))*exp(y(29));
  g1(50,45)=(-exp(y(45)));
  g1(50,56)=exp(y(29));
  g1(51,30)=(-(exp(y(30))*exp(y(47))))/(exp(y(30))*exp(y(30)));
  g1(51,47)=exp(y(47))/exp(y(30));
  g1(51,48)=(-exp(y(48)));
  g1(52,30)=(-(exp(y(30))*exp(y(44))))/(exp(y(30))*exp(y(30)));
  g1(52,44)=exp(y(44))/exp(y(30));
  g1(52,49)=(-exp(y(49)));
  g1(53,6)=exp(y(6))/exp(y(30));
  g1(53,30)=(-(exp(y(30))*exp(y(6))))/(exp(y(30))*exp(y(30)));
  g1(53,50)=(-exp(y(50)));
  g1(54,4)=exp(y(4))/exp(y(30));
  g1(54,30)=(-(exp(y(4))*exp(y(30))))/(exp(y(30))*exp(y(30)));
  g1(54,52)=(-exp(y(52)));
  g1(55,1)=exp(y(1))/exp(y(30));
  g1(55,30)=(-(exp(y(1))*exp(y(30))))/(exp(y(30))*exp(y(30)));
  g1(55,53)=(-exp(y(53)));
  g1(56,30)=(-(exp(y(30))*exp(y(45))))/(exp(y(30))*exp(y(30)));
  g1(56,45)=exp(y(45))/exp(y(30));
  g1(56,51)=(-exp(y(51)));
  g1(57,3)=exp(y(3))/exp(y(11));
  g1(57,11)=(-(exp(y(3))*exp(y(11))))/(exp(y(11))*exp(y(11)));
  g1(57,57)=(-exp(y(57)));
  g1(58,10)=T528*T533;
  g1(58,54)=exp(y(54));
  g1(58,55)=T528*exp(y(10))*exp(y(40))*params(2)*(1-params(5))*(1-params(13))/exp(y(40));
  g1(58,57)=T528*params(17)*exp(y(57));
  g1(58,58)=(-exp(y(58)));
  g1(59,10)=y(55)*params(6)*(-(params(2)*(1-params(5))*(1-params(13))*(-exp(y(10)))));
  g1(59,55)=params(6)*(1-params(2)*(1-params(5))*(1-params(13))*(1-exp(y(10))));
  g1(59,59)=(-exp(y(59)));
  g1(60,13)=exp(y(36))*(1-params(5))*exp(y(13));
  g1(60,36)=exp(y(36))*(1-params(5))*exp(y(13));
  g1(60,60)=(-exp(y(60)));
  g1(61,36)=exp(y(36))*params(5);
  g1(61,61)=(-exp(y(61)));
  g1(62,2)=exp(y(2))*(1-params(5))*exp(y(13));
  g1(62,13)=exp(y(2))*(1-params(5))*exp(y(13));
  g1(62,62)=(-exp(y(62)));
  g1(63,2)=params(5)*exp(y(2));
  g1(63,63)=(-exp(y(63)));
  g1(64,8)=exp(y(8))*exp(y(35));
  g1(64,35)=exp(y(8))*exp(y(35));
  g1(64,64)=(-exp(y(64)));
  g1(65,3)=exp(y(8))*exp(y(3));
  g1(65,8)=exp(y(8))*exp(y(3));
  g1(65,65)=(-exp(y(65)));
  g1(66,13)=(1-params(5))*exp(y(13));
  g1(66,66)=(-exp(y(66)));
  g1(67,66)=(-((1-params(13))*(-exp(y(66)))));
  g1(67,67)=(-exp(y(67)));
  g1(68,2)=exp(y(2))*exp(y(67))-exp(y(8))*params(5)*exp(y(2));
  g1(68,8)=(-(exp(y(8))*params(5)*exp(y(2))));
  g1(68,67)=exp(y(2))*exp(y(67));
  g1(68,68)=(-exp(y(68)));
  g1(69,2)=(-(exp(y(8))*params(5)*exp(y(2))));
  g1(69,3)=exp(y(8))*exp(y(3));
  g1(69,8)=exp(y(8))*exp(y(3))-exp(y(8))*params(5)*exp(y(2));
  g1(69,69)=(-exp(y(69)));
  g1(70,68)=(-exp(y(68)));
  g1(70,69)=exp(y(69));
  g1(70,70)=(-exp(y(70)));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],70,4900);
end
end
