function [residual, g1, g2, g3] = cycle_moments_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [M_.exo_nbr by nperiods] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(56, 1);
T26 = 1-exp(y(21));
T37 = (1-params(5))*T26*exp(y(3))*exp(y(6));
T53 = params(2)*exp(y(75))/exp(y(48));
T64 = (1-params(5))*(1-params(13))*T53*((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(63));
T85 = (1-params(6))/params(6)*exp(y(26));
T107 = exp(y(54))*exp(y(20))^params(20);
T111 = exp(y(1))^params(10);
T112 = T107*T111;
T116 = exp(y(10))^(1-params(10));
T161 = exp(y(42))/exp(y(36));
T174 = params(2)*(1-params(13))*exp(y(75))/exp(y(48));
T200 = exp(.5*(params(14)-exp(y(36)))/(exp(y(36))*params(14)*params(15)));
T220 = 1/exp(y(38))*exp(y(29))/exp(y(36));
T240 = y(63)*exp(y(44))*exp(y(21))*exp(y(36))/T26;
T255 = 1-params(12)/2*y(33)^2;
T274 = exp(y(14))/exp(y(2));
T277 = exp(y(32))*(T255-params(12)*y(33)*T274);
T284 = exp(y(65))/exp(y(14));
T286 = y(71)*T284^2;
T287 = exp(y(70))*T53*params(12)*T286;
T302 = (1-params(5))*(1-params(13))*T53*((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(76));
T313 = (1-params(5))*(1-params(13))*T53*(1-exp(y(66)))*exp(y(68));
T326 = exp(y(75))/exp(y(48))*params(2)*(1-params(5))*(1-params(13))*exp(y(18));
T328 = exp(y(68))*(1-exp(y(66)))*T326;
T336 = exp(y(44))*exp(y(37))/exp(y(16));
T339 = exp(y(10))/exp(y(36));
T343 = exp(y(1))/exp(y(36));
T353 = params(16)*exp(y(11))^(1-params(7));
T356 = exp(y(19))^params(7);
T365 = exp(y(17))/exp(y(19));
T369 = exp(y(17))/exp(y(11));
T378 = params(11)^0.5;
T384 = params(20)*params(9)^2;
T394 = (-0.5)*T378*exp(params(20)*0.5*(2*params(8)+T384)/(1-2*params(10)+params(10)^2));
T410 = 0.7071067811865475/params(9)*(params(8)+T384+(-log(exp(y(15))))+params(10)*log(exp(y(15)))-params(10)*params(8))/((-1)+params(10));
T430 = exp(params(10)*params(8)*(-params(20))/((-1)+params(10))^2);
T432 = T394*(erf(T410)-erf(0.7071067811865475*(params(8)+T384+(-10000000000)+params(10)*10000000000-params(10)*params(8))/params(9)/((-1)+params(10))))*T430/T378;
T443 = log(exp(y(15)))/(params(9)*1.414213562373095);
T452 = exp(y(42))*(1-params(10))*exp(y(31))/exp(y(10));
T455 = exp(y(15))/exp(y(20));
T458 = exp(y(22))*T455^params(21);
T464 = exp(y(42))*params(10)*exp(y(31))/exp(y(1));
T546 = exp(y(55))/exp(y(38));
T552 = exp(y(52))/exp(y(38));
T558 = exp(y(14))/exp(y(38));
T564 = exp(y(12))/exp(y(38));
T570 = exp(y(9))/exp(y(38));
T576 = exp(y(53))/exp(y(38));
T607 = exp(y(10))*getPowerDeriv(exp(y(10)),1-params(10),1);
T613 = (-(exp(y(10))*exp(y(42))*(1-params(10))*exp(y(31))))/(exp(y(10))*exp(y(10)));
T623 = (-(exp(y(11))*exp(y(17))))/(exp(y(11))*exp(y(11)));
T627 = exp(y(1))*getPowerDeriv(exp(y(1)),params(10),1);
T628 = T107*T627;
T633 = (-(exp(y(1))*exp(y(42))*params(10)*exp(y(31))))/(exp(y(1))*exp(y(1)));
T637 = (-(exp(y(14))*exp(y(2))))/(exp(y(2))*exp(y(2)));
T646 = (-(exp(y(14))*exp(y(65))))/(exp(y(14))*exp(y(14)));
T656 = 0.7071067811865475/params(9)*((-1)+params(10))/((-1)+params(10));
T660 = exp(T410^2)*1.772453850905516;
T665 = T430*T394*T656*2/T660/T378;
T669 = exp(T443^2);
T679 = exp(y(16))*exp(y(16));
T691 = (-(exp(y(16))*exp(y(44))*exp(y(37))))/T679;
T693 = exp(y(19))*getPowerDeriv(exp(y(19)),params(7),1);
T698 = (-(exp(y(17))*exp(y(19))))/(exp(y(19))*exp(y(19)));
T701 = exp(y(54))*exp(y(20))*getPowerDeriv(exp(y(20)),params(20),1);
T702 = T111*T701;
T707 = (-(exp(y(20))*exp(y(15))))/(exp(y(20))*exp(y(20)));
T708 = getPowerDeriv(T455,params(21),1)*T707;
T718 = T26*T26;
T720 = (-((T26*y(63)*exp(y(44))*exp(y(21))-y(63)*exp(y(44))*exp(y(21))*(-exp(y(21))))/T718));
T722 = y(63)*exp(y(44))*exp(y(21))*exp(y(36))*(-exp(y(21)));
T724 = (T26*y(63)*exp(y(44))*exp(y(21))*exp(y(36))-T722)/T718;
T733 = (1-params(5))*(1-params(13))*T53*(exp(y(67))*(-exp(y(66)))-exp(y(66))*y(63));
T735 = (1-params(5))*(1-params(13))*T53*(exp(y(67))*(-exp(y(66)))-exp(y(66))*y(76));
T736 = (1-params(5))*(1-params(13))*T53*(-exp(y(66)));
T743 = (1-params(5))*(1-params(13))*T53*(1-exp(y(66)))*exp(y(67));
T753 = exp(y(70))*T53*params(12)*T284^2;
T759 = exp(y(36))*exp(y(36));
T765 = exp(y(36))*params(14)*params(15)*exp(y(36))*params(14)*params(15);
T766 = (exp(y(36))*params(14)*params(15)*(-exp(y(36)))*.5-.5*(params(14)-exp(y(36)))*exp(y(36))*params(14)*params(15))/T765;
T770 = (-(exp(y(36))*1/exp(y(38))*exp(y(29))));
T771 = T770/T759;
T782 = exp(y(38))*exp(y(38));
T784 = exp(y(29))*(-exp(y(38)))/T782;
T785 = T784/exp(y(36));
T810 = (-(exp(y(44))*exp(y(12))))-y(63)*exp(y(44))*exp(y(21))/T26;
T816 = (-(params(2)*exp(y(75))*exp(y(48))))/(exp(y(48))*exp(y(48)));
T821 = (-(exp(y(75))*exp(y(48))))/(exp(y(48))*exp(y(48)));
T834 = exp(y(68))*(1-exp(y(66)))*exp(y(18))*params(2)*(1-params(5))*(1-params(13))*T821;
T836 = exp(y(49))*getPowerDeriv(exp(y(49)),(1-params(10))/params(20),1);
T841 = exp(y(44))*exp(y(21))*exp(y(36))/T26;
T856 = ((-(params(2)*exp(y(75))*exp(y(48))))*exp(y(48))*exp(y(48))-(-(params(2)*exp(y(75))*exp(y(48))))*(exp(y(48))*exp(y(48))+exp(y(48))*exp(y(48))))/(exp(y(48))*exp(y(48))*exp(y(48))*exp(y(48)));
T919 = (exp(y(48))*exp(y(48))*(-(exp(y(75))*exp(y(48))))-(-(exp(y(75))*exp(y(48))))*(exp(y(48))*exp(y(48))+exp(y(48))*exp(y(48))))/(exp(y(48))*exp(y(48))*exp(y(48))*exp(y(48)));
T981 = ((-(exp(y(14))*exp(y(2))))*exp(y(2))*exp(y(2))-(-(exp(y(14))*exp(y(2))))*(exp(y(2))*exp(y(2))+exp(y(2))*exp(y(2))))/(exp(y(2))*exp(y(2))*exp(y(2))*exp(y(2)));
lhs =y(46);
rhs =log(exp(y(9)));
residual(1)= lhs-rhs;
lhs =y(47);
rhs =y(46)+params(2)*y(74);
residual(2)= lhs-rhs;
residual(3) = (-exp(y(44)))+(1-params(5))*T26*exp(y(7))+T37;
residual(4) = (-params(17))/exp(y(16))+T64;
residual(5) = (-exp(y(50)))+exp(y(28))-params(17)/exp(y(16))-y(63);
residual(6) = (-exp(y(25)))+T85;
residual(7) = (-exp(y(28)))+exp(y(12))-params(6)*(exp(y(22))-exp(y(50)));
residual(8) = (-exp(y(42)))+T112*T116;
residual(9) = (-exp(y(35)))+exp(y(38))*exp(y(41))-exp(y(44))*exp(y(12))-params(17)*exp(y(43))-exp(y(23))*exp(y(45))-y(63)*exp(y(44))*exp(y(21))/T26;
residual(10) = (-exp(y(34)))+params(18)+y(64)+params(17)*(exp(y(43))+exp(y(44))/exp(y(16)));
residual(11) = (-exp(y(41)))+T161;
residual(12) = (-exp(y(38)))+exp(y(40))*exp(y(31));
residual(13) = (-exp(y(34)))+T174*(exp(y(72))+exp(y(73)));
residual(14) = (-exp(y(36)))+(1-params(13))*(exp(y(4))+exp(y(5)));
residual(15) = (-1)+exp(y(38))*T200;
residual(16) = (-exp(y(40)))+exp(y(39))/(exp(y(39))-1);
residual(17) = (-exp(y(39)))+1+exp(y(36))*params(15);
residual(18) = (-exp(y(41)))+T220;
residual(19) = (-exp(y(29)))+exp(y(52))+exp(y(14))+params(17)*exp(y(11))+(params(18)+y(64))*exp(y(37))+T240;
residual(20) = (-exp(y(13)))+exp(y(1))*(1-params(19))+exp(y(14))*T255;
residual(21) = (-exp(y(32)))+T53*(exp(y(69))+(1-params(19))*exp(y(70)));
residual(22) = (-1)+T277+T287;
residual(23) = T274-y(33)-1;
residual(24) = T302+exp(y(22))-exp(y(24))-exp(y(12));
residual(25) = T313+exp(y(12))-exp(y(26))-exp(y(27));
residual(26) = (-exp(y(27)))+params(23)+exp(y(62))+T328;
residual(27) = (-exp(y(11)))+exp(y(43))*(exp(y(36))+exp(y(37)))+T336;
residual(28) = (-exp(y(44)))+T339;
residual(29) = (-exp(y(45)))+T343;
residual(30) = (-exp(y(17)))+T353*T356;
residual(31) = 1-exp(y(19))-exp(y(10));
residual(32) = (-exp(y(18)))+T365;
residual(33) = (-exp(y(16)))+T369;
residual(34) = (-exp(y(49)))+T432/T26;
residual(35) = (-exp(y(20)))+exp(y(49))^((1-params(10))/params(20));
residual(36) = (-exp(y(21)))+0.5+0.5*erf(T443);
residual(37) = (-exp(y(22)))+T452;
residual(38) = (-exp(y(50)))+T458;
residual(39) = (-exp(y(23)))+T464;
residual(40) = y(63)+(-exp(y(25)))+exp(y(24));
residual(41) = exp(y(23))-exp(y(30));
residual(42) = exp(y(9))-exp(y(52))-params(23)*(1-exp(y(10)));
residual(43) = (-exp(y(48)))+exp(y(9))^(-params(1));
residual(44) = (-y(54))+params(3)*y(8)-x(it_, 1);
residual(45) = (-exp(y(62)))+params(24)*params(88)/params(89)+params(25)*(log(exp(y(56)))-log(params(91)));
residual(46) = (-y(63))+params(71);
residual(47) = (-y(64))+params(72);
residual(48) = T26*(1-params(5))*params(13)+(1-params(5))*exp(y(21))+params(5)-exp(y(51));
residual(49) = (-exp(y(55)))+exp(y(12))*exp(y(10))+exp(y(1))*exp(y(30))+exp(y(35))*exp(y(36));
residual(50) = (params(18)+y(64))*exp(y(37))-exp(y(53));
residual(51) = (-exp(y(56)))+T546;
residual(52) = (-exp(y(57)))+T552;
residual(53) = (-exp(y(58)))+T558;
residual(54) = (-exp(y(60)))+T564;
residual(55) = (-exp(y(61)))+T570;
residual(56) = (-exp(y(59)))+T576;
if nargout >= 2,
  g1 = zeros(56, 77);

  %
  % Jacobian matrix
  %

  g1(1,9)=(-1);
  g1(1,46)=1;
  g1(2,46)=(-1);
  g1(2,47)=1;
  g1(2,74)=(-params(2));
  g1(3,3)=T37;
  g1(3,21)=exp(y(7))*(1-params(5))*(-exp(y(21)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(21)));
  g1(3,6)=T37;
  g1(3,7)=(1-params(5))*T26*exp(y(7));
  g1(3,44)=(-exp(y(44)));
  g1(4,16)=(-((-params(17))*exp(y(16))))/T679;
  g1(4,66)=T733;
  g1(4,67)=T743;
  g1(4,48)=((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(63))*(1-params(5))*(1-params(13))*T816;
  g1(4,75)=T64;
  g1(4,63)=T736;
  g1(5,16)=(-((-(params(17)*exp(y(16))))/T679));
  g1(5,28)=exp(y(28));
  g1(5,50)=(-exp(y(50)));
  g1(5,63)=(-1);
  g1(6,25)=(-exp(y(25)));
  g1(6,26)=T85;
  g1(7,12)=exp(y(12));
  g1(7,22)=(-(params(6)*exp(y(22))));
  g1(7,28)=(-exp(y(28)));
  g1(7,50)=(-((-exp(y(50)))*params(6)));
  g1(8,10)=T112*T607;
  g1(8,1)=T116*T628;
  g1(8,20)=T116*T702;
  g1(8,42)=(-exp(y(42)));
  g1(8,54)=T112*T116;
  g1(9,12)=(-(exp(y(44))*exp(y(12))));
  g1(9,21)=T720;
  g1(9,23)=(-(exp(y(23))*exp(y(45))));
  g1(9,35)=(-exp(y(35)));
  g1(9,38)=exp(y(38))*exp(y(41));
  g1(9,41)=exp(y(38))*exp(y(41));
  g1(9,43)=(-(params(17)*exp(y(43))));
  g1(9,44)=T810;
  g1(9,45)=(-(exp(y(23))*exp(y(45))));
  g1(9,63)=(-(exp(y(44))*exp(y(21))/T26));
  g1(10,16)=params(17)*(-(exp(y(44))*exp(y(16))))/T679;
  g1(10,34)=(-exp(y(34)));
  g1(10,43)=params(17)*exp(y(43));
  g1(10,44)=params(17)*exp(y(44))/exp(y(16));
  g1(10,64)=1;
  g1(11,36)=(-(exp(y(42))*exp(y(36))))/T759;
  g1(11,41)=(-exp(y(41)));
  g1(11,42)=T161;
  g1(12,31)=exp(y(40))*exp(y(31));
  g1(12,38)=(-exp(y(38)));
  g1(12,40)=exp(y(40))*exp(y(31));
  g1(13,34)=(-exp(y(34)));
  g1(13,72)=T174*exp(y(72));
  g1(13,73)=T174*exp(y(73));
  g1(13,48)=(exp(y(72))+exp(y(73)))*params(2)*(1-params(13))*T821;
  g1(13,75)=T174*(exp(y(72))+exp(y(73)));
  g1(14,4)=(1-params(13))*exp(y(4));
  g1(14,36)=(-exp(y(36)));
  g1(14,5)=(1-params(13))*exp(y(5));
  g1(15,36)=exp(y(38))*T200*T766;
  g1(15,38)=exp(y(38))*T200;
  g1(16,39)=(exp(y(39))*(exp(y(39))-1)-exp(y(39))*exp(y(39)))/((exp(y(39))-1)*(exp(y(39))-1));
  g1(16,40)=(-exp(y(40)));
  g1(17,36)=exp(y(36))*params(15);
  g1(17,39)=(-exp(y(39)));
  g1(18,29)=T220;
  g1(18,36)=T771;
  g1(18,38)=T785;
  g1(18,41)=(-exp(y(41)));
  g1(19,11)=params(17)*exp(y(11));
  g1(19,14)=exp(y(14));
  g1(19,21)=T724;
  g1(19,29)=(-exp(y(29)));
  g1(19,36)=T240;
  g1(19,37)=(params(18)+y(64))*exp(y(37));
  g1(19,44)=T240;
  g1(19,52)=exp(y(52));
  g1(19,63)=T841;
  g1(19,64)=exp(y(37));
  g1(20,1)=exp(y(1))*(1-params(19));
  g1(20,13)=(-exp(y(13)));
  g1(20,14)=exp(y(14))*T255;
  g1(20,33)=exp(y(14))*(-(params(12)/2*2*y(33)));
  g1(21,69)=T53*exp(y(69));
  g1(21,32)=(-exp(y(32)));
  g1(21,70)=T53*(1-params(19))*exp(y(70));
  g1(21,48)=(exp(y(69))+(1-params(19))*exp(y(70)))*T816;
  g1(21,75)=T53*(exp(y(69))+(1-params(19))*exp(y(70)));
  g1(22,2)=exp(y(32))*(-(params(12)*y(33)*T637));
  g1(22,14)=exp(y(32))*(-(params(12)*y(33)*T274))+exp(y(70))*T53*params(12)*y(71)*T646*2*T284;
  g1(22,65)=exp(y(70))*T53*params(12)*y(71)*T284*2*T284;
  g1(22,32)=T277;
  g1(22,70)=T287;
  g1(22,33)=exp(y(32))*((-(params(12)/2*2*y(33)))-params(12)*T274);
  g1(22,71)=T753;
  g1(22,48)=T286*exp(y(70))*params(12)*T816;
  g1(22,75)=T287;
  g1(23,2)=T637;
  g1(23,14)=T274;
  g1(23,33)=(-1);
  g1(24,12)=(-exp(y(12)));
  g1(24,66)=T735;
  g1(24,22)=exp(y(22));
  g1(24,24)=(-exp(y(24)));
  g1(24,67)=T743;
  g1(24,48)=((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(76))*(1-params(5))*(1-params(13))*T816;
  g1(24,75)=T302;
  g1(24,76)=T736;
  g1(25,12)=exp(y(12));
  g1(25,66)=exp(y(68))*T736;
  g1(25,26)=(-exp(y(26)));
  g1(25,68)=T313;
  g1(25,27)=(-exp(y(27)));
  g1(25,48)=exp(y(68))*(1-exp(y(66)))*(1-params(5))*(1-params(13))*T816;
  g1(25,75)=T313;
  g1(26,18)=T328;
  g1(26,66)=exp(y(68))*T326*(-exp(y(66)));
  g1(26,68)=T328;
  g1(26,27)=(-exp(y(27)));
  g1(26,48)=T834;
  g1(26,75)=T328;
  g1(26,62)=exp(y(62));
  g1(27,11)=(-exp(y(11)));
  g1(27,16)=T691;
  g1(27,36)=exp(y(43))*exp(y(36));
  g1(27,37)=T336+exp(y(43))*exp(y(37));
  g1(27,43)=exp(y(43))*(exp(y(36))+exp(y(37)));
  g1(27,44)=T336;
  g1(28,10)=T339;
  g1(28,36)=(-(exp(y(10))*exp(y(36))))/T759;
  g1(28,44)=(-exp(y(44)));
  g1(29,1)=T343;
  g1(29,36)=(-(exp(y(1))*exp(y(36))))/T759;
  g1(29,45)=(-exp(y(45)));
  g1(30,11)=T356*params(16)*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(7),1);
  g1(30,17)=(-exp(y(17)));
  g1(30,19)=T353*T693;
  g1(31,10)=(-exp(y(10)));
  g1(31,19)=(-exp(y(19)));
  g1(32,17)=T365;
  g1(32,18)=(-exp(y(18)));
  g1(32,19)=T698;
  g1(33,11)=T623;
  g1(33,16)=(-exp(y(16)));
  g1(33,17)=T369;
  g1(34,15)=T665/T26;
  g1(34,21)=(-(T432*(-exp(y(21)))))/T718;
  g1(34,49)=(-exp(y(49)));
  g1(35,20)=(-exp(y(20)));
  g1(35,49)=T836;
  g1(36,15)=0.5*1/(params(9)*1.414213562373095)*2/(1.772453850905516*T669);
  g1(36,21)=(-exp(y(21)));
  g1(37,10)=T613;
  g1(37,22)=(-exp(y(22)));
  g1(37,31)=T452;
  g1(37,42)=T452;
  g1(38,15)=exp(y(22))*T455*getPowerDeriv(T455,params(21),1);
  g1(38,20)=exp(y(22))*T708;
  g1(38,22)=T458;
  g1(38,50)=(-exp(y(50)));
  g1(39,1)=T633;
  g1(39,23)=(-exp(y(23)));
  g1(39,31)=T464;
  g1(39,42)=T464;
  g1(40,24)=exp(y(24));
  g1(40,25)=(-exp(y(25)));
  g1(40,63)=1;
  g1(41,23)=exp(y(23));
  g1(41,30)=(-exp(y(30)));
  g1(42,9)=exp(y(9));
  g1(42,10)=(-(params(23)*(-exp(y(10)))));
  g1(42,52)=(-exp(y(52)));
  g1(43,9)=exp(y(9))*getPowerDeriv(exp(y(9)),(-params(1)),1);
  g1(43,48)=(-exp(y(48)));
  g1(44,8)=params(3);
  g1(44,54)=(-1);
  g1(44,77)=(-1);
  g1(45,56)=params(25);
  g1(45,62)=(-exp(y(62)));
  g1(46,63)=(-1);
  g1(47,64)=(-1);
  g1(48,21)=(1-params(5))*exp(y(21))+(-exp(y(21)))*(1-params(5))*params(13);
  g1(48,51)=(-exp(y(51)));
  g1(49,10)=exp(y(12))*exp(y(10));
  g1(49,12)=exp(y(12))*exp(y(10));
  g1(49,1)=exp(y(1))*exp(y(30));
  g1(49,30)=exp(y(1))*exp(y(30));
  g1(49,35)=exp(y(35))*exp(y(36));
  g1(49,36)=exp(y(35))*exp(y(36));
  g1(49,55)=(-exp(y(55)));
  g1(50,37)=(params(18)+y(64))*exp(y(37));
  g1(50,53)=(-exp(y(53)));
  g1(50,64)=exp(y(37));
  g1(51,38)=(-(exp(y(38))*exp(y(55))))/T782;
  g1(51,55)=T546;
  g1(51,56)=(-exp(y(56)));
  g1(52,38)=(-(exp(y(38))*exp(y(52))))/T782;
  g1(52,52)=T552;
  g1(52,57)=(-exp(y(57)));
  g1(53,14)=T558;
  g1(53,38)=(-(exp(y(38))*exp(y(14))))/T782;
  g1(53,58)=(-exp(y(58)));
  g1(54,12)=T564;
  g1(54,38)=(-(exp(y(12))*exp(y(38))))/T782;
  g1(54,60)=(-exp(y(60)));
  g1(55,9)=T570;
  g1(55,38)=(-(exp(y(9))*exp(y(38))))/T782;
  g1(55,61)=(-exp(y(61)));
  g1(56,38)=(-(exp(y(38))*exp(y(53))))/T782;
  g1(56,53)=T576;
  g1(56,59)=(-exp(y(59)));
end
if nargout >= 3,
  %
  % Hessian matrix
  %

  v2 = zeros(444,3);
  v2(1,1)=3;
  v2(1,2)=157;
  v2(1,3)=T37;
  v2(2,1)=3;
  v2(2,2)=1543;
  v2(2,3)=exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(21)));
  v2(3,1)=3;
  v2(3,2)=175;
  v2(3,3)=  v2(2,3);
  v2(4,1)=3;
  v2(4,2)=1561;
  v2(4,3)=exp(y(7))*(1-params(5))*(-exp(y(21)))+exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(21)));
  v2(5,1)=3;
  v2(5,2)=388;
  v2(5,3)=T37;
  v2(6,1)=3;
  v2(6,2)=160;
  v2(6,3)=  v2(5,3);
  v2(7,1)=3;
  v2(7,2)=406;
  v2(7,3)=exp(y(6))*exp(y(3))*(1-params(5))*(-exp(y(21)));
  v2(8,1)=3;
  v2(8,2)=1546;
  v2(8,3)=  v2(7,3);
  v2(9,1)=3;
  v2(9,2)=391;
  v2(9,3)=T37;
  v2(10,1)=3;
  v2(10,2)=483;
  v2(10,3)=exp(y(7))*(1-params(5))*(-exp(y(21)));
  v2(11,1)=3;
  v2(11,2)=1547;
  v2(11,3)=  v2(10,3);
  v2(12,1)=3;
  v2(12,2)=469;
  v2(12,3)=(1-params(5))*T26*exp(y(7));
  v2(13,1)=3;
  v2(13,2)=3355;
  v2(13,3)=(-exp(y(44)));
  v2(14,1)=4;
  v2(14,2)=1171;
  v2(14,3)=((-((-params(17))*exp(y(16))))*T679-(-((-params(17))*exp(y(16))))*(T679+T679))/(T679*T679);
  v2(15,1)=4;
  v2(15,2)=5071;
  v2(15,3)=T733;
  v2(16,1)=4;
  v2(16,2)=5148;
  v2(16,3)=(1-params(5))*(1-params(13))*T53*exp(y(67))*(-exp(y(66)));
  v2(17,1)=4;
  v2(17,2)=5072;
  v2(17,3)=  v2(16,3);
  v2(18,1)=4;
  v2(18,2)=5149;
  v2(18,3)=T743;
  v2(19,1)=4;
  v2(19,2)=3685;
  v2(19,3)=(exp(y(67))*(-exp(y(66)))-exp(y(66))*y(63))*(1-params(5))*(1-params(13))*T816;
  v2(20,1)=4;
  v2(20,2)=5053;
  v2(20,3)=  v2(19,3);
  v2(21,1)=4;
  v2(21,2)=3686;
  v2(21,3)=(1-exp(y(66)))*exp(y(67))*(1-params(5))*(1-params(13))*T816;
  v2(22,1)=4;
  v2(22,2)=5130;
  v2(22,3)=  v2(21,3);
  v2(23,1)=4;
  v2(23,2)=3667;
  v2(23,3)=((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(63))*(1-params(5))*(1-params(13))*T856;
  v2(24,1)=4;
  v2(24,2)=5764;
  v2(24,3)=T733;
  v2(25,1)=4;
  v2(25,2)=5080;
  v2(25,3)=  v2(24,3);
  v2(26,1)=4;
  v2(26,2)=5765;
  v2(26,3)=T743;
  v2(27,1)=4;
  v2(27,2)=5157;
  v2(27,3)=  v2(26,3);
  v2(28,1)=4;
  v2(28,2)=5746;
  v2(28,3)=((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(63))*(1-params(5))*(1-params(13))*T816;
  v2(29,1)=4;
  v2(29,2)=3694;
  v2(29,3)=  v2(28,3);
  v2(30,1)=4;
  v2(30,2)=5773;
  v2(30,3)=T64;
  v2(31,1)=4;
  v2(31,2)=4840;
  v2(31,3)=T736;
  v2(32,1)=4;
  v2(32,2)=5068;
  v2(32,3)=  v2(31,3);
  v2(33,1)=4;
  v2(33,2)=4822;
  v2(33,3)=(-exp(y(66)))*(1-params(5))*(1-params(13))*T816;
  v2(34,1)=4;
  v2(34,2)=3682;
  v2(34,3)=  v2(33,3);
  v2(35,1)=4;
  v2(35,2)=4849;
  v2(35,3)=T736;
  v2(36,1)=4;
  v2(36,2)=5761;
  v2(36,3)=  v2(35,3);
  v2(37,1)=5;
  v2(37,2)=1171;
  v2(37,3)=(-((T679*(-(params(17)*exp(y(16))))-(-(params(17)*exp(y(16))))*(T679+T679))/(T679*T679)));
  v2(38,1)=5;
  v2(38,2)=2107;
  v2(38,3)=exp(y(28));
  v2(39,1)=5;
  v2(39,2)=3823;
  v2(39,3)=(-exp(y(50)));
  v2(40,1)=6;
  v2(40,2)=1873;
  v2(40,3)=(-exp(y(25)));
  v2(41,1)=6;
  v2(41,2)=1951;
  v2(41,3)=T85;
  v2(42,1)=7;
  v2(42,2)=859;
  v2(42,3)=exp(y(12));
  v2(43,1)=7;
  v2(43,2)=1639;
  v2(43,3)=(-(params(6)*exp(y(22))));
  v2(44,1)=7;
  v2(44,2)=2107;
  v2(44,3)=(-exp(y(28)));
  v2(45,1)=7;
  v2(45,2)=3823;
  v2(45,3)=(-((-exp(y(50)))*params(6)));
  v2(46,1)=8;
  v2(46,2)=703;
  v2(46,3)=T112*(T607+exp(y(10))*exp(y(10))*getPowerDeriv(exp(y(10)),1-params(10),2));
  v2(47,1)=8;
  v2(47,2)=10;
  v2(47,3)=T607*T628;
  v2(48,1)=8;
  v2(48,2)=694;
  v2(48,3)=  v2(47,3);
  v2(49,1)=8;
  v2(49,2)=1;
  v2(49,3)=T116*T107*(T627+exp(y(1))*exp(y(1))*getPowerDeriv(exp(y(1)),params(10),2));
  v2(50,1)=8;
  v2(50,2)=1473;
  v2(50,3)=T607*T702;
  v2(51,1)=8;
  v2(51,2)=713;
  v2(51,3)=  v2(50,3);
  v2(52,1)=8;
  v2(52,2)=1464;
  v2(52,3)=T116*T627*T701;
  v2(53,1)=8;
  v2(53,2)=20;
  v2(53,3)=  v2(52,3);
  v2(54,1)=8;
  v2(54,2)=1483;
  v2(54,3)=T116*T111*exp(y(54))*(exp(y(20))*getPowerDeriv(exp(y(20)),params(20),1)+exp(y(20))*exp(y(20))*getPowerDeriv(exp(y(20)),params(20),2));
  v2(55,1)=8;
  v2(55,2)=3199;
  v2(55,3)=(-exp(y(42)));
  v2(56,1)=8;
  v2(56,2)=4091;
  v2(56,3)=T112*T607;
  v2(57,1)=8;
  v2(57,2)=747;
  v2(57,3)=  v2(56,3);
  v2(58,1)=8;
  v2(58,2)=4082;
  v2(58,3)=T116*T628;
  v2(59,1)=8;
  v2(59,2)=54;
  v2(59,3)=  v2(58,3);
  v2(60,1)=8;
  v2(60,2)=4101;
  v2(60,3)=T116*T702;
  v2(61,1)=8;
  v2(61,2)=1517;
  v2(61,3)=  v2(60,3);
  v2(62,1)=8;
  v2(62,2)=4135;
  v2(62,3)=T112*T116;
  v2(63,1)=9;
  v2(63,2)=859;
  v2(63,3)=(-(exp(y(44))*exp(y(12))));
  v2(64,1)=9;
  v2(64,2)=1561;
  v2(64,3)=(-((T718*(T26*y(63)*exp(y(44))*exp(y(21))+y(63)*exp(y(44))*exp(y(21))*(-exp(y(21)))-(y(63)*exp(y(44))*exp(y(21))*(-exp(y(21)))+y(63)*exp(y(44))*exp(y(21))*(-exp(y(21)))))-(T26*y(63)*exp(y(44))*exp(y(21))-y(63)*exp(y(44))*exp(y(21))*(-exp(y(21))))*(T26*(-exp(y(21)))+T26*(-exp(y(21)))))/(T718*T718)));
  v2(65,1)=9;
  v2(65,2)=1717;
  v2(65,3)=(-(exp(y(23))*exp(y(45))));
  v2(66,1)=9;
  v2(66,2)=2653;
  v2(66,3)=(-exp(y(35)));
  v2(67,1)=9;
  v2(67,2)=2887;
  v2(67,3)=exp(y(38))*exp(y(41));
  v2(68,1)=9;
  v2(68,2)=3118;
  v2(68,3)=exp(y(38))*exp(y(41));
  v2(69,1)=9;
  v2(69,2)=2890;
  v2(69,3)=  v2(68,3);
  v2(70,1)=9;
  v2(70,2)=3121;
  v2(70,3)=exp(y(38))*exp(y(41));
  v2(71,1)=9;
  v2(71,2)=3277;
  v2(71,3)=(-(params(17)*exp(y(43))));
  v2(72,1)=9;
  v2(72,2)=3323;
  v2(72,3)=(-(exp(y(44))*exp(y(12))));
  v2(73,1)=9;
  v2(73,2)=891;
  v2(73,3)=  v2(72,3);
  v2(74,1)=9;
  v2(74,2)=3332;
  v2(74,3)=T720;
  v2(75,1)=9;
  v2(75,2)=1584;
  v2(75,3)=  v2(74,3);
  v2(76,1)=9;
  v2(76,2)=3355;
  v2(76,3)=T810;
  v2(77,1)=9;
  v2(77,2)=3411;
  v2(77,3)=(-(exp(y(23))*exp(y(45))));
  v2(78,1)=9;
  v2(78,2)=1739;
  v2(78,3)=  v2(77,3);
  v2(79,1)=9;
  v2(79,2)=3433;
  v2(79,3)=(-(exp(y(23))*exp(y(45))));
  v2(80,1)=9;
  v2(80,2)=4795;
  v2(80,3)=(-((T26*exp(y(44))*exp(y(21))-exp(y(44))*exp(y(21))*(-exp(y(21))))/T718));
  v2(81,1)=9;
  v2(81,2)=1603;
  v2(81,3)=  v2(80,3);
  v2(82,1)=9;
  v2(82,2)=4818;
  v2(82,3)=(-(exp(y(44))*exp(y(21))/T26));
  v2(83,1)=9;
  v2(83,2)=3374;
  v2(83,3)=  v2(82,3);
  v2(84,1)=10;
  v2(84,2)=1171;
  v2(84,3)=params(17)*(T679*(-(exp(y(44))*exp(y(16))))-(-(exp(y(44))*exp(y(16))))*(T679+T679))/(T679*T679);
  v2(85,1)=10;
  v2(85,2)=2575;
  v2(85,3)=(-exp(y(34)));
  v2(86,1)=10;
  v2(86,2)=3277;
  v2(86,3)=params(17)*exp(y(43));
  v2(87,1)=10;
  v2(87,2)=3327;
  v2(87,3)=params(17)*(-(exp(y(44))*exp(y(16))))/T679;
  v2(88,1)=10;
  v2(88,2)=1199;
  v2(88,3)=  v2(87,3);
  v2(89,1)=10;
  v2(89,2)=3355;
  v2(89,3)=params(17)*exp(y(44))/exp(y(16));
  v2(90,1)=11;
  v2(90,2)=2731;
  v2(90,3)=((-(exp(y(42))*exp(y(36))))*T759-(-(exp(y(42))*exp(y(36))))*(T759+T759))/(T759*T759);
  v2(91,1)=11;
  v2(91,2)=3121;
  v2(91,3)=(-exp(y(41)));
  v2(92,1)=11;
  v2(92,2)=3193;
  v2(92,3)=(-(exp(y(42))*exp(y(36))))/T759;
  v2(93,1)=11;
  v2(93,2)=2737;
  v2(93,3)=  v2(92,3);
  v2(94,1)=11;
  v2(94,2)=3199;
  v2(94,3)=T161;
  v2(95,1)=12;
  v2(95,2)=2341;
  v2(95,3)=exp(y(40))*exp(y(31));
  v2(96,1)=12;
  v2(96,2)=2887;
  v2(96,3)=(-exp(y(38)));
  v2(97,1)=12;
  v2(97,2)=3034;
  v2(97,3)=exp(y(40))*exp(y(31));
  v2(98,1)=12;
  v2(98,2)=2350;
  v2(98,3)=  v2(97,3);
  v2(99,1)=12;
  v2(99,2)=3043;
  v2(99,3)=exp(y(40))*exp(y(31));
  v2(100,1)=13;
  v2(100,2)=2575;
  v2(100,3)=(-exp(y(34)));
  v2(101,1)=13;
  v2(101,2)=5539;
  v2(101,3)=T174*exp(y(72));
  v2(102,1)=13;
  v2(102,2)=5617;
  v2(102,3)=T174*exp(y(73));
  v2(103,1)=13;
  v2(103,2)=3691;
  v2(103,3)=exp(y(72))*params(2)*(1-params(13))*T821;
  v2(104,1)=13;
  v2(104,2)=5515;
  v2(104,3)=  v2(103,3);
  v2(105,1)=13;
  v2(105,2)=3692;
  v2(105,3)=exp(y(73))*params(2)*(1-params(13))*T821;
  v2(106,1)=13;
  v2(106,2)=5592;
  v2(106,3)=  v2(105,3);
  v2(107,1)=13;
  v2(107,2)=3667;
  v2(107,3)=(exp(y(72))+exp(y(73)))*params(2)*(1-params(13))*T919;
  v2(108,1)=13;
  v2(108,2)=5770;
  v2(108,3)=T174*exp(y(72));
  v2(109,1)=13;
  v2(109,2)=5542;
  v2(109,3)=  v2(108,3);
  v2(110,1)=13;
  v2(110,2)=5771;
  v2(110,3)=T174*exp(y(73));
  v2(111,1)=13;
  v2(111,2)=5619;
  v2(111,3)=  v2(110,3);
  v2(112,1)=13;
  v2(112,2)=5746;
  v2(112,3)=(exp(y(72))+exp(y(73)))*params(2)*(1-params(13))*T821;
  v2(113,1)=13;
  v2(113,2)=3694;
  v2(113,3)=  v2(112,3);
  v2(114,1)=13;
  v2(114,2)=5773;
  v2(114,3)=T174*(exp(y(72))+exp(y(73)));
  v2(115,1)=14;
  v2(115,2)=235;
  v2(115,3)=(1-params(13))*exp(y(4));
  v2(116,1)=14;
  v2(116,2)=2731;
  v2(116,3)=(-exp(y(36)));
  v2(117,1)=14;
  v2(117,2)=313;
  v2(117,3)=(1-params(13))*exp(y(5));
  v2(118,1)=15;
  v2(118,2)=2731;
  v2(118,3)=exp(y(38))*(T766*T200*T766+T200*(T765*(exp(y(36))*params(14)*params(15)*(-exp(y(36)))*.5+exp(y(36))*params(14)*params(15)*(-exp(y(36)))*.5-(exp(y(36))*params(14)*params(15)*(-exp(y(36)))*.5+.5*(params(14)-exp(y(36)))*exp(y(36))*params(14)*params(15)))-(exp(y(36))*params(14)*params(15)*(-exp(y(36)))*.5-.5*(params(14)-exp(y(36)))*exp(y(36))*params(14)*params(15))*(T765+T765))/(T765*T765));
  v2(119,1)=15;
  v2(119,2)=2885;
  v2(119,3)=exp(y(38))*T200*T766;
  v2(120,1)=15;
  v2(120,2)=2733;
  v2(120,3)=  v2(119,3);
  v2(121,1)=15;
  v2(121,2)=2887;
  v2(121,3)=exp(y(38))*T200;
  v2(122,1)=16;
  v2(122,2)=2965;
  v2(122,3)=((exp(y(39))-1)*(exp(y(39))-1)*(exp(y(39))*(exp(y(39))-1)+exp(y(39))*exp(y(39))-(exp(y(39))*exp(y(39))+exp(y(39))*exp(y(39))))-(exp(y(39))*(exp(y(39))-1)-exp(y(39))*exp(y(39)))*(exp(y(39))*(exp(y(39))-1)+exp(y(39))*(exp(y(39))-1)))/((exp(y(39))-1)*(exp(y(39))-1)*(exp(y(39))-1)*(exp(y(39))-1));
  v2(123,1)=16;
  v2(123,2)=3043;
  v2(123,3)=(-exp(y(40)));
  v2(124,1)=17;
  v2(124,2)=2731;
  v2(124,3)=exp(y(36))*params(15);
  v2(125,1)=17;
  v2(125,2)=2965;
  v2(125,3)=(-exp(y(39)));
  v2(126,1)=18;
  v2(126,2)=2185;
  v2(126,3)=T220;
  v2(127,1)=18;
  v2(127,2)=2724;
  v2(127,3)=T771;
  v2(128,1)=18;
  v2(128,2)=2192;
  v2(128,3)=  v2(127,3);
  v2(129,1)=18;
  v2(129,2)=2731;
  v2(129,3)=(T759*T770-T770*(T759+T759))/(T759*T759);
  v2(130,1)=18;
  v2(130,2)=2878;
  v2(130,3)=T785;
  v2(131,1)=18;
  v2(131,2)=2194;
  v2(131,3)=  v2(130,3);
  v2(132,1)=18;
  v2(132,2)=2885;
  v2(132,3)=(-(exp(y(36))*T784))/T759;
  v2(133,1)=18;
  v2(133,2)=2733;
  v2(133,3)=  v2(132,3);
  v2(134,1)=18;
  v2(134,2)=2887;
  v2(134,3)=exp(y(29))*((-exp(y(38)))*T782-(-exp(y(38)))*(T782+T782))/(T782*T782)/exp(y(36));
  v2(135,1)=18;
  v2(135,2)=3121;
  v2(135,3)=(-exp(y(41)));
  v2(136,1)=19;
  v2(136,2)=781;
  v2(136,3)=params(17)*exp(y(11));
  v2(137,1)=19;
  v2(137,2)=1015;
  v2(137,3)=exp(y(14));
  v2(138,1)=19;
  v2(138,2)=1561;
  v2(138,3)=(T718*(T26*y(63)*exp(y(44))*exp(y(21))*exp(y(36))+T722-(T722+T722))-(T26*y(63)*exp(y(44))*exp(y(21))*exp(y(36))-T722)*(T26*(-exp(y(21)))+T26*(-exp(y(21)))))/(T718*T718);
  v2(139,1)=19;
  v2(139,2)=2185;
  v2(139,3)=(-exp(y(29)));
  v2(140,1)=19;
  v2(140,2)=2716;
  v2(140,3)=T724;
  v2(141,1)=19;
  v2(141,2)=1576;
  v2(141,3)=  v2(140,3);
  v2(142,1)=19;
  v2(142,2)=2731;
  v2(142,3)=T240;
  v2(143,1)=19;
  v2(143,2)=2809;
  v2(143,3)=(params(18)+y(64))*exp(y(37));
  v2(144,1)=19;
  v2(144,2)=3332;
  v2(144,3)=T724;
  v2(145,1)=19;
  v2(145,2)=1584;
  v2(145,3)=  v2(144,3);
  v2(146,1)=19;
  v2(146,2)=3347;
  v2(146,3)=T240;
  v2(147,1)=19;
  v2(147,2)=2739;
  v2(147,3)=  v2(146,3);
  v2(148,1)=19;
  v2(148,2)=3355;
  v2(148,3)=T240;
  v2(149,1)=19;
  v2(149,2)=3979;
  v2(149,3)=exp(y(52));
  v2(150,1)=19;
  v2(150,2)=4795;
  v2(150,3)=(T26*exp(y(44))*exp(y(21))*exp(y(36))-exp(y(44))*exp(y(21))*exp(y(36))*(-exp(y(21))))/T718;
  v2(151,1)=19;
  v2(151,2)=1603;
  v2(151,3)=  v2(150,3);
  v2(152,1)=19;
  v2(152,2)=4810;
  v2(152,3)=T841;
  v2(153,1)=19;
  v2(153,2)=2758;
  v2(153,3)=  v2(152,3);
  v2(154,1)=19;
  v2(154,2)=4818;
  v2(154,3)=T841;
  v2(155,1)=19;
  v2(155,2)=3374;
  v2(155,3)=  v2(154,3);
  v2(156,1)=19;
  v2(156,2)=4888;
  v2(156,3)=exp(y(37));
  v2(157,1)=19;
  v2(157,2)=2836;
  v2(157,3)=  v2(156,3);
  v2(158,1)=20;
  v2(158,2)=1;
  v2(158,3)=exp(y(1))*(1-params(19));
  v2(159,1)=20;
  v2(159,2)=937;
  v2(159,3)=(-exp(y(13)));
  v2(160,1)=20;
  v2(160,2)=1015;
  v2(160,3)=exp(y(14))*T255;
  v2(161,1)=20;
  v2(161,2)=2478;
  v2(161,3)=exp(y(14))*(-(params(12)/2*2*y(33)));
  v2(162,1)=20;
  v2(162,2)=1034;
  v2(162,3)=  v2(161,3);
  v2(163,1)=20;
  v2(163,2)=2497;
  v2(163,3)=exp(y(14))*(-(2*params(12)/2));
  v2(164,1)=21;
  v2(164,2)=5305;
  v2(164,3)=T53*exp(y(69));
  v2(165,1)=21;
  v2(165,2)=2419;
  v2(165,3)=(-exp(y(32)));
  v2(166,1)=21;
  v2(166,2)=5383;
  v2(166,3)=T53*(1-params(19))*exp(y(70));
  v2(167,1)=21;
  v2(167,2)=3688;
  v2(167,3)=exp(y(69))*T816;
  v2(168,1)=21;
  v2(168,2)=5284;
  v2(168,3)=  v2(167,3);
  v2(169,1)=21;
  v2(169,2)=3689;
  v2(169,3)=(1-params(19))*exp(y(70))*T816;
  v2(170,1)=21;
  v2(170,2)=5361;
  v2(170,3)=  v2(169,3);
  v2(171,1)=21;
  v2(171,2)=3667;
  v2(171,3)=(exp(y(69))+(1-params(19))*exp(y(70)))*T856;
  v2(172,1)=21;
  v2(172,2)=5767;
  v2(172,3)=T53*exp(y(69));
  v2(173,1)=21;
  v2(173,2)=5311;
  v2(173,3)=  v2(172,3);
  v2(174,1)=21;
  v2(174,2)=5768;
  v2(174,3)=T53*(1-params(19))*exp(y(70));
  v2(175,1)=21;
  v2(175,2)=5388;
  v2(175,3)=  v2(174,3);
  v2(176,1)=21;
  v2(176,2)=5746;
  v2(176,3)=(exp(y(69))+(1-params(19))*exp(y(70)))*T816;
  v2(177,1)=21;
  v2(177,2)=3694;
  v2(177,3)=  v2(176,3);
  v2(178,1)=21;
  v2(178,2)=5773;
  v2(178,3)=T53*(exp(y(69))+(1-params(19))*exp(y(70)));
  v2(179,1)=22;
  v2(179,2)=79;
  v2(179,3)=exp(y(32))*(-(params(12)*y(33)*T981));
  v2(180,1)=22;
  v2(180,2)=1003;
  v2(180,3)=exp(y(32))*(-(params(12)*y(33)*T637));
  v2(181,1)=22;
  v2(181,2)=91;
  v2(181,3)=  v2(180,3);
  v2(182,1)=22;
  v2(182,2)=1015;
  v2(182,3)=exp(y(32))*(-(params(12)*y(33)*T274))+exp(y(70))*T53*params(12)*y(71)*(2*T284*((-(exp(y(14))*exp(y(65))))*exp(y(14))*exp(y(14))-(-(exp(y(14))*exp(y(65))))*(exp(y(14))*exp(y(14))+exp(y(14))*exp(y(14))))/(exp(y(14))*exp(y(14))*exp(y(14))*exp(y(14)))+T646*2*T646);
  v2(183,1)=22;
  v2(183,2)=4942;
  v2(183,3)=exp(y(70))*T53*params(12)*y(71)*(T646*2*T284+T284*2*T646);
  v2(184,1)=22;
  v2(184,2)=1066;
  v2(184,3)=  v2(183,3);
  v2(185,1)=22;
  v2(185,2)=4993;
  v2(185,3)=exp(y(70))*T53*params(12)*y(71)*(T284*2*T284+T284*2*T284);
  v2(186,1)=22;
  v2(186,2)=2389;
  v2(186,3)=exp(y(32))*(-(params(12)*y(33)*T637));
  v2(187,1)=22;
  v2(187,2)=109;
  v2(187,3)=  v2(186,3);
  v2(188,1)=22;
  v2(188,2)=2401;
  v2(188,3)=exp(y(32))*(-(params(12)*y(33)*T274));
  v2(189,1)=22;
  v2(189,2)=1033;
  v2(189,3)=  v2(188,3);
  v2(190,1)=22;
  v2(190,2)=2419;
  v2(190,3)=T277;
  v2(191,1)=22;
  v2(191,2)=5327;
  v2(191,3)=exp(y(70))*T53*params(12)*y(71)*T646*2*T284;
  v2(192,1)=22;
  v2(192,2)=1071;
  v2(192,3)=  v2(191,3);
  v2(193,1)=22;
  v2(193,2)=5378;
  v2(193,3)=exp(y(70))*T53*params(12)*y(71)*T284*2*T284;
  v2(194,1)=22;
  v2(194,2)=4998;
  v2(194,3)=  v2(193,3);
  v2(195,1)=22;
  v2(195,2)=5383;
  v2(195,3)=T287;
  v2(196,1)=22;
  v2(196,2)=2466;
  v2(196,3)=exp(y(32))*(-(params(12)*T637));
  v2(197,1)=22;
  v2(197,2)=110;
  v2(197,3)=  v2(196,3);
  v2(198,1)=22;
  v2(198,2)=2478;
  v2(198,3)=exp(y(32))*(-(params(12)*T274));
  v2(199,1)=22;
  v2(199,2)=1034;
  v2(199,3)=  v2(198,3);
  v2(200,1)=22;
  v2(200,2)=2496;
  v2(200,3)=exp(y(32))*((-(params(12)/2*2*y(33)))-params(12)*T274);
  v2(201,1)=22;
  v2(201,2)=2420;
  v2(201,3)=  v2(200,3);
  v2(202,1)=22;
  v2(202,2)=2497;
  v2(202,3)=exp(y(32))*(-(2*params(12)/2));
  v2(203,1)=22;
  v2(203,2)=5404;
  v2(203,3)=exp(y(70))*T53*params(12)*T646*2*T284;
  v2(204,1)=22;
  v2(204,2)=1072;
  v2(204,3)=  v2(203,3);
  v2(205,1)=22;
  v2(205,2)=5455;
  v2(205,3)=exp(y(70))*T53*params(12)*T284*2*T284;
  v2(206,1)=22;
  v2(206,2)=4999;
  v2(206,3)=  v2(205,3);
  v2(207,1)=22;
  v2(207,2)=5460;
  v2(207,3)=T753;
  v2(208,1)=22;
  v2(208,2)=5384;
  v2(208,3)=  v2(207,3);
  v2(209,1)=22;
  v2(209,2)=3633;
  v2(209,3)=y(71)*T646*2*T284*exp(y(70))*params(12)*T816;
  v2(210,1)=22;
  v2(210,2)=1049;
  v2(210,3)=  v2(209,3);
  v2(211,1)=22;
  v2(211,2)=3684;
  v2(211,3)=y(71)*T284*2*T284*exp(y(70))*params(12)*T816;
  v2(212,1)=22;
  v2(212,2)=4976;
  v2(212,3)=  v2(211,3);
  v2(213,1)=22;
  v2(213,2)=3689;
  v2(213,3)=T286*exp(y(70))*params(12)*T816;
  v2(214,1)=22;
  v2(214,2)=5361;
  v2(214,3)=  v2(213,3);
  v2(215,1)=22;
  v2(215,2)=3690;
  v2(215,3)=T284^2*exp(y(70))*params(12)*T816;
  v2(216,1)=22;
  v2(216,2)=5438;
  v2(216,3)=  v2(215,3);
  v2(217,1)=22;
  v2(217,2)=3667;
  v2(217,3)=T286*exp(y(70))*params(12)*T856;
  v2(218,1)=22;
  v2(218,2)=5712;
  v2(218,3)=exp(y(70))*T53*params(12)*y(71)*T646*2*T284;
  v2(219,1)=22;
  v2(219,2)=1076;
  v2(219,3)=  v2(218,3);
  v2(220,1)=22;
  v2(220,2)=5763;
  v2(220,3)=exp(y(70))*T53*params(12)*y(71)*T284*2*T284;
  v2(221,1)=22;
  v2(221,2)=5003;
  v2(221,3)=  v2(220,3);
  v2(222,1)=22;
  v2(222,2)=5768;
  v2(222,3)=T287;
  v2(223,1)=22;
  v2(223,2)=5388;
  v2(223,3)=  v2(222,3);
  v2(224,1)=22;
  v2(224,2)=5769;
  v2(224,3)=T753;
  v2(225,1)=22;
  v2(225,2)=5465;
  v2(225,3)=  v2(224,3);
  v2(226,1)=22;
  v2(226,2)=5746;
  v2(226,3)=T286*exp(y(70))*params(12)*T816;
  v2(227,1)=22;
  v2(227,2)=3694;
  v2(227,3)=  v2(226,3);
  v2(228,1)=22;
  v2(228,2)=5773;
  v2(228,3)=T287;
  v2(229,1)=23;
  v2(229,2)=79;
  v2(229,3)=T981;
  v2(230,1)=23;
  v2(230,2)=1003;
  v2(230,3)=T637;
  v2(231,1)=23;
  v2(231,2)=91;
  v2(231,3)=  v2(230,3);
  v2(232,1)=23;
  v2(232,2)=1015;
  v2(232,3)=T274;
  v2(233,1)=24;
  v2(233,2)=859;
  v2(233,3)=(-exp(y(12)));
  v2(234,1)=24;
  v2(234,2)=5071;
  v2(234,3)=T735;
  v2(235,1)=24;
  v2(235,2)=1639;
  v2(235,3)=exp(y(22));
  v2(236,1)=24;
  v2(236,2)=1795;
  v2(236,3)=(-exp(y(24)));
  v2(237,1)=24;
  v2(237,2)=5148;
  v2(237,3)=(1-params(5))*(1-params(13))*T53*exp(y(67))*(-exp(y(66)));
  v2(238,1)=24;
  v2(238,2)=5072;
  v2(238,3)=  v2(237,3);
  v2(239,1)=24;
  v2(239,2)=5149;
  v2(239,3)=T743;
  v2(240,1)=24;
  v2(240,2)=3685;
  v2(240,3)=(exp(y(67))*(-exp(y(66)))-exp(y(66))*y(76))*(1-params(5))*(1-params(13))*T816;
  v2(241,1)=24;
  v2(241,2)=5053;
  v2(241,3)=  v2(240,3);
  v2(242,1)=24;
  v2(242,2)=3686;
  v2(242,3)=(1-exp(y(66)))*exp(y(67))*(1-params(5))*(1-params(13))*T816;
  v2(243,1)=24;
  v2(243,2)=5130;
  v2(243,3)=  v2(242,3);
  v2(244,1)=24;
  v2(244,2)=3667;
  v2(244,3)=((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(76))*(1-params(5))*(1-params(13))*T856;
  v2(245,1)=24;
  v2(245,2)=5764;
  v2(245,3)=T735;
  v2(246,1)=24;
  v2(246,2)=5080;
  v2(246,3)=  v2(245,3);
  v2(247,1)=24;
  v2(247,2)=5765;
  v2(247,3)=T743;
  v2(248,1)=24;
  v2(248,2)=5157;
  v2(248,3)=  v2(247,3);
  v2(249,1)=24;
  v2(249,2)=5746;
  v2(249,3)=((1-exp(y(66)))*exp(y(67))-exp(y(66))*y(76))*(1-params(5))*(1-params(13))*T816;
  v2(250,1)=24;
  v2(250,2)=3694;
  v2(250,3)=  v2(249,3);
  v2(251,1)=24;
  v2(251,2)=5773;
  v2(251,3)=T302;
  v2(252,1)=24;
  v2(252,2)=5841;
  v2(252,3)=T736;
  v2(253,1)=24;
  v2(253,2)=5081;
  v2(253,3)=  v2(252,3);
  v2(254,1)=24;
  v2(254,2)=5823;
  v2(254,3)=(-exp(y(66)))*(1-params(5))*(1-params(13))*T816;
  v2(255,1)=24;
  v2(255,2)=3695;
  v2(255,3)=  v2(254,3);
  v2(256,1)=24;
  v2(256,2)=5850;
  v2(256,3)=T736;
  v2(257,1)=24;
  v2(257,2)=5774;
  v2(257,3)=  v2(256,3);
  v2(258,1)=25;
  v2(258,2)=859;
  v2(258,3)=exp(y(12));
  v2(259,1)=25;
  v2(259,2)=5071;
  v2(259,3)=exp(y(68))*T736;
  v2(260,1)=25;
  v2(260,2)=1951;
  v2(260,3)=(-exp(y(26)));
  v2(261,1)=25;
  v2(261,2)=5225;
  v2(261,3)=exp(y(68))*T736;
  v2(262,1)=25;
  v2(262,2)=5073;
  v2(262,3)=  v2(261,3);
  v2(263,1)=25;
  v2(263,2)=5227;
  v2(263,3)=T313;
  v2(264,1)=25;
  v2(264,2)=2029;
  v2(264,3)=(-exp(y(27)));
  v2(265,1)=25;
  v2(265,2)=3685;
  v2(265,3)=exp(y(68))*(-exp(y(66)))*(1-params(5))*(1-params(13))*T816;
  v2(266,1)=25;
  v2(266,2)=5053;
  v2(266,3)=  v2(265,3);
  v2(267,1)=25;
  v2(267,2)=3687;
  v2(267,3)=exp(y(68))*(1-exp(y(66)))*(1-params(5))*(1-params(13))*T816;
  v2(268,1)=25;
  v2(268,2)=5207;
  v2(268,3)=  v2(267,3);
  v2(269,1)=25;
  v2(269,2)=3667;
  v2(269,3)=exp(y(68))*(1-exp(y(66)))*(1-params(5))*(1-params(13))*T856;
  v2(270,1)=25;
  v2(270,2)=5764;
  v2(270,3)=exp(y(68))*T736;
  v2(271,1)=25;
  v2(271,2)=5080;
  v2(271,3)=  v2(270,3);
  v2(272,1)=25;
  v2(272,2)=5766;
  v2(272,3)=T313;
  v2(273,1)=25;
  v2(273,2)=5234;
  v2(273,3)=  v2(272,3);
  v2(274,1)=25;
  v2(274,2)=5746;
  v2(274,3)=exp(y(68))*(1-exp(y(66)))*(1-params(5))*(1-params(13))*T816;
  v2(275,1)=25;
  v2(275,2)=3694;
  v2(275,3)=  v2(274,3);
  v2(276,1)=25;
  v2(276,2)=5773;
  v2(276,3)=T313;
  v2(277,1)=26;
  v2(277,2)=1327;
  v2(277,3)=T328;
  v2(278,1)=26;
  v2(278,2)=5023;
  v2(278,3)=exp(y(68))*T326*(-exp(y(66)));
  v2(279,1)=26;
  v2(279,2)=1375;
  v2(279,3)=  v2(278,3);
  v2(280,1)=26;
  v2(280,2)=5071;
  v2(280,3)=exp(y(68))*T326*(-exp(y(66)));
  v2(281,1)=26;
  v2(281,2)=5177;
  v2(281,3)=T328;
  v2(282,1)=26;
  v2(282,2)=1377;
  v2(282,3)=  v2(281,3);
  v2(283,1)=26;
  v2(283,2)=5225;
  v2(283,3)=exp(y(68))*T326*(-exp(y(66)));
  v2(284,1)=26;
  v2(284,2)=5073;
  v2(284,3)=  v2(283,3);
  v2(285,1)=26;
  v2(285,2)=5227;
  v2(285,3)=T328;
  v2(286,1)=26;
  v2(286,2)=2029;
  v2(286,3)=(-exp(y(27)));
  v2(287,1)=26;
  v2(287,2)=3637;
  v2(287,3)=T834;
  v2(288,1)=26;
  v2(288,2)=1357;
  v2(288,3)=  v2(287,3);
  v2(289,1)=26;
  v2(289,2)=3685;
  v2(289,3)=exp(y(68))*(-exp(y(66)))*exp(y(18))*params(2)*(1-params(5))*(1-params(13))*T821;
  v2(290,1)=26;
  v2(290,2)=5053;
  v2(290,3)=  v2(289,3);
  v2(291,1)=26;
  v2(291,2)=3687;
  v2(291,3)=T834;
  v2(292,1)=26;
  v2(292,2)=5207;
  v2(292,3)=  v2(291,3);
  v2(293,1)=26;
  v2(293,2)=3667;
  v2(293,3)=exp(y(68))*(1-exp(y(66)))*exp(y(18))*params(2)*(1-params(5))*(1-params(13))*T919;
  v2(294,1)=26;
  v2(294,2)=5716;
  v2(294,3)=T328;
  v2(295,1)=26;
  v2(295,2)=1384;
  v2(295,3)=  v2(294,3);
  v2(296,1)=26;
  v2(296,2)=5764;
  v2(296,3)=exp(y(68))*T326*(-exp(y(66)));
  v2(297,1)=26;
  v2(297,2)=5080;
  v2(297,3)=  v2(296,3);
  v2(298,1)=26;
  v2(298,2)=5766;
  v2(298,3)=T328;
  v2(299,1)=26;
  v2(299,2)=5234;
  v2(299,3)=  v2(298,3);
  v2(300,1)=26;
  v2(300,2)=5746;
  v2(300,3)=T834;
  v2(301,1)=26;
  v2(301,2)=3694;
  v2(301,3)=  v2(300,3);
  v2(302,1)=26;
  v2(302,2)=5773;
  v2(302,3)=T328;
  v2(303,1)=26;
  v2(303,2)=4759;
  v2(303,3)=exp(y(62));
  v2(304,1)=27;
  v2(304,2)=781;
  v2(304,3)=(-exp(y(11)));
  v2(305,1)=27;
  v2(305,2)=1171;
  v2(305,3)=(T679*(-(exp(y(16))*exp(y(44))*exp(y(37))))-(-(exp(y(16))*exp(y(44))*exp(y(37))))*(T679+T679))/(T679*T679);
  v2(306,1)=27;
  v2(306,2)=2731;
  v2(306,3)=exp(y(43))*exp(y(36));
  v2(307,1)=27;
  v2(307,2)=2788;
  v2(307,3)=T691;
  v2(308,1)=27;
  v2(308,2)=1192;
  v2(308,3)=  v2(307,3);
  v2(309,1)=27;
  v2(309,2)=2809;
  v2(309,3)=T336+exp(y(43))*exp(y(37));
  v2(310,1)=27;
  v2(310,2)=3270;
  v2(310,3)=exp(y(43))*exp(y(36));
  v2(311,1)=27;
  v2(311,2)=2738;
  v2(311,3)=  v2(310,3);
  v2(312,1)=27;
  v2(312,2)=3271;
  v2(312,3)=exp(y(43))*exp(y(37));
  v2(313,1)=27;
  v2(313,2)=2815;
  v2(313,3)=  v2(312,3);
  v2(314,1)=27;
  v2(314,2)=3277;
  v2(314,3)=exp(y(43))*(exp(y(36))+exp(y(37)));
  v2(315,1)=27;
  v2(315,2)=3327;
  v2(315,3)=T691;
  v2(316,1)=27;
  v2(316,2)=1199;
  v2(316,3)=  v2(315,3);
  v2(317,1)=27;
  v2(317,2)=3348;
  v2(317,3)=T336;
  v2(318,1)=27;
  v2(318,2)=2816;
  v2(318,3)=  v2(317,3);
  v2(319,1)=27;
  v2(319,2)=3355;
  v2(319,3)=T336;
  v2(320,1)=28;
  v2(320,2)=703;
  v2(320,3)=T339;
  v2(321,1)=28;
  v2(321,2)=2705;
  v2(321,3)=(-(exp(y(10))*exp(y(36))))/T759;
  v2(322,1)=28;
  v2(322,2)=729;
  v2(322,3)=  v2(321,3);
  v2(323,1)=28;
  v2(323,2)=2731;
  v2(323,3)=(T759*(-(exp(y(10))*exp(y(36))))-(-(exp(y(10))*exp(y(36))))*(T759+T759))/(T759*T759);
  v2(324,1)=28;
  v2(324,2)=3355;
  v2(324,3)=(-exp(y(44)));
  v2(325,1)=29;
  v2(325,2)=1;
  v2(325,3)=T343;
  v2(326,1)=29;
  v2(326,2)=2696;
  v2(326,3)=(-(exp(y(1))*exp(y(36))))/T759;
  v2(327,1)=29;
  v2(327,2)=36;
  v2(327,3)=  v2(326,3);
  v2(328,1)=29;
  v2(328,2)=2731;
  v2(328,3)=(T759*(-(exp(y(1))*exp(y(36))))-(-(exp(y(1))*exp(y(36))))*(T759+T759))/(T759*T759);
  v2(329,1)=29;
  v2(329,2)=3433;
  v2(329,3)=(-exp(y(45)));
  v2(330,1)=30;
  v2(330,2)=781;
  v2(330,3)=T356*params(16)*(exp(y(11))*getPowerDeriv(exp(y(11)),1-params(7),1)+exp(y(11))*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(7),2));
  v2(331,1)=30;
  v2(331,2)=1249;
  v2(331,3)=(-exp(y(17)));
  v2(332,1)=30;
  v2(332,2)=1397;
  v2(332,3)=params(16)*exp(y(11))*getPowerDeriv(exp(y(11)),1-params(7),1)*T693;
  v2(333,1)=30;
  v2(333,2)=789;
  v2(333,3)=  v2(332,3);
  v2(334,1)=30;
  v2(334,2)=1405;
  v2(334,3)=T353*(T693+exp(y(19))*exp(y(19))*getPowerDeriv(exp(y(19)),params(7),2));
  v2(335,1)=31;
  v2(335,2)=703;
  v2(335,3)=(-exp(y(10)));
  v2(336,1)=31;
  v2(336,2)=1405;
  v2(336,3)=(-exp(y(19)));
  v2(337,1)=32;
  v2(337,2)=1249;
  v2(337,3)=T365;
  v2(338,1)=32;
  v2(338,2)=1327;
  v2(338,3)=(-exp(y(18)));
  v2(339,1)=32;
  v2(339,2)=1403;
  v2(339,3)=T698;
  v2(340,1)=32;
  v2(340,2)=1251;
  v2(340,3)=  v2(339,3);
  v2(341,1)=32;
  v2(341,2)=1405;
  v2(341,3)=((-(exp(y(17))*exp(y(19))))*exp(y(19))*exp(y(19))-(-(exp(y(17))*exp(y(19))))*(exp(y(19))*exp(y(19))+exp(y(19))*exp(y(19))))/(exp(y(19))*exp(y(19))*exp(y(19))*exp(y(19)));
  v2(342,1)=33;
  v2(342,2)=781;
  v2(342,3)=((-(exp(y(11))*exp(y(17))))*exp(y(11))*exp(y(11))-(-(exp(y(11))*exp(y(17))))*(exp(y(11))*exp(y(11))+exp(y(11))*exp(y(11))))/(exp(y(11))*exp(y(11))*exp(y(11))*exp(y(11)));
  v2(343,1)=33;
  v2(343,2)=1171;
  v2(343,3)=(-exp(y(16)));
  v2(344,1)=33;
  v2(344,2)=1243;
  v2(344,3)=T623;
  v2(345,1)=33;
  v2(345,2)=787;
  v2(345,3)=  v2(344,3);
  v2(346,1)=33;
  v2(346,2)=1249;
  v2(346,3)=T369;
  v2(347,1)=34;
  v2(347,2)=1093;
  v2(347,3)=T430*T394*T656*(-(2*1.772453850905516*exp(T410^2)*T656*2*T410))/(T660*T660)/T378/T26;
  v2(348,1)=34;
  v2(348,2)=1555;
  v2(348,3)=(-((-exp(y(21)))*T665))/T718;
  v2(349,1)=34;
  v2(349,2)=1099;
  v2(349,3)=  v2(348,3);
  v2(350,1)=34;
  v2(350,2)=1561;
  v2(350,3)=(T718*(-(T432*(-exp(y(21)))))-(-(T432*(-exp(y(21)))))*(T26*(-exp(y(21)))+T26*(-exp(y(21)))))/(T718*T718);
  v2(351,1)=34;
  v2(351,2)=3745;
  v2(351,3)=(-exp(y(49)));
  v2(352,1)=35;
  v2(352,2)=1483;
  v2(352,3)=(-exp(y(20)));
  v2(353,1)=35;
  v2(353,2)=3745;
  v2(353,3)=T836+exp(y(49))*exp(y(49))*getPowerDeriv(exp(y(49)),(1-params(10))/params(20),2);
  v2(354,1)=36;
  v2(354,2)=1093;
  v2(354,3)=0.5*1/(params(9)*1.414213562373095)*(-(2*1.772453850905516*T669*1/(params(9)*1.414213562373095)*2*T443))/(1.772453850905516*T669*1.772453850905516*T669);
  v2(355,1)=36;
  v2(355,2)=1561;
  v2(355,3)=(-exp(y(21)));
  v2(356,1)=37;
  v2(356,2)=703;
  v2(356,3)=((-(exp(y(10))*exp(y(42))*(1-params(10))*exp(y(31))))*exp(y(10))*exp(y(10))-(-(exp(y(10))*exp(y(42))*(1-params(10))*exp(y(31))))*(exp(y(10))*exp(y(10))+exp(y(10))*exp(y(10))))/(exp(y(10))*exp(y(10))*exp(y(10))*exp(y(10)));
  v2(357,1)=37;
  v2(357,2)=1639;
  v2(357,3)=(-exp(y(22)));
  v2(358,1)=37;
  v2(358,2)=2320;
  v2(358,3)=T613;
  v2(359,1)=37;
  v2(359,2)=724;
  v2(359,3)=  v2(358,3);
  v2(360,1)=37;
  v2(360,2)=2341;
  v2(360,3)=T452;
  v2(361,1)=37;
  v2(361,2)=3167;
  v2(361,3)=T613;
  v2(362,1)=37;
  v2(362,2)=735;
  v2(362,3)=  v2(361,3);
  v2(363,1)=37;
  v2(363,2)=3188;
  v2(363,3)=T452;
  v2(364,1)=37;
  v2(364,2)=2352;
  v2(364,3)=  v2(363,3);
  v2(365,1)=37;
  v2(365,2)=3199;
  v2(365,3)=T452;
  v2(366,1)=38;
  v2(366,2)=1093;
  v2(366,3)=exp(y(22))*(T455*getPowerDeriv(T455,params(21),1)+T455*T455*getPowerDeriv(T455,params(21),2));
  v2(367,1)=38;
  v2(367,2)=1478;
  v2(367,3)=exp(y(22))*(T708+T707*T455*getPowerDeriv(T455,params(21),2));
  v2(368,1)=38;
  v2(368,2)=1098;
  v2(368,3)=  v2(367,3);
  v2(369,1)=38;
  v2(369,2)=1483;
  v2(369,3)=exp(y(22))*(T707*T707*getPowerDeriv(T455,params(21),2)+getPowerDeriv(T455,params(21),1)*((-(exp(y(20))*exp(y(15))))*exp(y(20))*exp(y(20))-(-(exp(y(20))*exp(y(15))))*(exp(y(20))*exp(y(20))+exp(y(20))*exp(y(20))))/(exp(y(20))*exp(y(20))*exp(y(20))*exp(y(20))));
  v2(370,1)=38;
  v2(370,2)=1632;
  v2(370,3)=exp(y(22))*T455*getPowerDeriv(T455,params(21),1);
  v2(371,1)=38;
  v2(371,2)=1100;
  v2(371,3)=  v2(370,3);
  v2(372,1)=38;
  v2(372,2)=1637;
  v2(372,3)=exp(y(22))*T708;
  v2(373,1)=38;
  v2(373,2)=1485;
  v2(373,3)=  v2(372,3);
  v2(374,1)=38;
  v2(374,2)=1639;
  v2(374,3)=T458;
  v2(375,1)=38;
  v2(375,2)=3823;
  v2(375,3)=(-exp(y(50)));
  v2(376,1)=39;
  v2(376,2)=1;
  v2(376,3)=((-(exp(y(1))*exp(y(42))*params(10)*exp(y(31))))*exp(y(1))*exp(y(1))-(-(exp(y(1))*exp(y(42))*params(10)*exp(y(31))))*(exp(y(1))*exp(y(1))+exp(y(1))*exp(y(1))))/(exp(y(1))*exp(y(1))*exp(y(1))*exp(y(1)));
  v2(377,1)=39;
  v2(377,2)=1717;
  v2(377,3)=(-exp(y(23)));
  v2(378,1)=39;
  v2(378,2)=2311;
  v2(378,3)=T633;
  v2(379,1)=39;
  v2(379,2)=31;
  v2(379,3)=  v2(378,3);
  v2(380,1)=39;
  v2(380,2)=2341;
  v2(380,3)=T464;
  v2(381,1)=39;
  v2(381,2)=3158;
  v2(381,3)=T633;
  v2(382,1)=39;
  v2(382,2)=42;
  v2(382,3)=  v2(381,3);
  v2(383,1)=39;
  v2(383,2)=3188;
  v2(383,3)=T464;
  v2(384,1)=39;
  v2(384,2)=2352;
  v2(384,3)=  v2(383,3);
  v2(385,1)=39;
  v2(385,2)=3199;
  v2(385,3)=T464;
  v2(386,1)=40;
  v2(386,2)=1795;
  v2(386,3)=exp(y(24));
  v2(387,1)=40;
  v2(387,2)=1873;
  v2(387,3)=(-exp(y(25)));
  v2(388,1)=41;
  v2(388,2)=1717;
  v2(388,3)=exp(y(23));
  v2(389,1)=41;
  v2(389,2)=2263;
  v2(389,3)=(-exp(y(30)));
  v2(390,1)=42;
  v2(390,2)=625;
  v2(390,3)=exp(y(9));
  v2(391,1)=42;
  v2(391,2)=703;
  v2(391,3)=(-(params(23)*(-exp(y(10)))));
  v2(392,1)=42;
  v2(392,2)=3979;
  v2(392,3)=(-exp(y(52)));
  v2(393,1)=43;
  v2(393,2)=625;
  v2(393,3)=exp(y(9))*getPowerDeriv(exp(y(9)),(-params(1)),1)+exp(y(9))*exp(y(9))*getPowerDeriv(exp(y(9)),(-params(1)),2);
  v2(394,1)=43;
  v2(394,2)=3667;
  v2(394,3)=(-exp(y(48)));
  v2(395,1)=45;
  v2(395,2)=4759;
  v2(395,3)=(-exp(y(62)));
  v2(396,1)=48;
  v2(396,2)=1561;
  v2(396,3)=(1-params(5))*exp(y(21))+(-exp(y(21)))*(1-params(5))*params(13);
  v2(397,1)=48;
  v2(397,2)=3901;
  v2(397,3)=(-exp(y(51)));
  v2(398,1)=49;
  v2(398,2)=703;
  v2(398,3)=exp(y(12))*exp(y(10));
  v2(399,1)=49;
  v2(399,2)=857;
  v2(399,3)=exp(y(12))*exp(y(10));
  v2(400,1)=49;
  v2(400,2)=705;
  v2(400,3)=  v2(399,3);
  v2(401,1)=49;
  v2(401,2)=859;
  v2(401,3)=exp(y(12))*exp(y(10));
  v2(402,1)=49;
  v2(402,2)=1;
  v2(402,3)=exp(y(1))*exp(y(30));
  v2(403,1)=49;
  v2(403,2)=2234;
  v2(403,3)=exp(y(1))*exp(y(30));
  v2(404,1)=49;
  v2(404,2)=30;
  v2(404,3)=  v2(403,3);
  v2(405,1)=49;
  v2(405,2)=2263;
  v2(405,3)=exp(y(1))*exp(y(30));
  v2(406,1)=49;
  v2(406,2)=2653;
  v2(406,3)=exp(y(35))*exp(y(36));
  v2(407,1)=49;
  v2(407,2)=2730;
  v2(407,3)=exp(y(35))*exp(y(36));
  v2(408,1)=49;
  v2(408,2)=2654;
  v2(408,3)=  v2(407,3);
  v2(409,1)=49;
  v2(409,2)=2731;
  v2(409,3)=exp(y(35))*exp(y(36));
  v2(410,1)=49;
  v2(410,2)=4213;
  v2(410,3)=(-exp(y(55)));
  v2(411,1)=50;
  v2(411,2)=2809;
  v2(411,3)=(params(18)+y(64))*exp(y(37));
  v2(412,1)=50;
  v2(412,2)=4057;
  v2(412,3)=(-exp(y(53)));
  v2(413,1)=50;
  v2(413,2)=4888;
  v2(413,3)=exp(y(37));
  v2(414,1)=50;
  v2(414,2)=2836;
  v2(414,3)=  v2(413,3);
  v2(415,1)=51;
  v2(415,2)=2887;
  v2(415,3)=(T782*(-(exp(y(38))*exp(y(55))))-(-(exp(y(38))*exp(y(55))))*(T782+T782))/(T782*T782);
  v2(416,1)=51;
  v2(416,2)=4196;
  v2(416,3)=(-(exp(y(38))*exp(y(55))))/T782;
  v2(417,1)=51;
  v2(417,2)=2904;
  v2(417,3)=  v2(416,3);
  v2(418,1)=51;
  v2(418,2)=4213;
  v2(418,3)=T546;
  v2(419,1)=51;
  v2(419,2)=4291;
  v2(419,3)=(-exp(y(56)));
  v2(420,1)=52;
  v2(420,2)=2887;
  v2(420,3)=(T782*(-(exp(y(38))*exp(y(52))))-(-(exp(y(38))*exp(y(52))))*(T782+T782))/(T782*T782);
  v2(421,1)=52;
  v2(421,2)=3965;
  v2(421,3)=(-(exp(y(38))*exp(y(52))))/T782;
  v2(422,1)=52;
  v2(422,2)=2901;
  v2(422,3)=  v2(421,3);
  v2(423,1)=52;
  v2(423,2)=3979;
  v2(423,3)=T552;
  v2(424,1)=52;
  v2(424,2)=4369;
  v2(424,3)=(-exp(y(57)));
  v2(425,1)=53;
  v2(425,2)=1015;
  v2(425,3)=T558;
  v2(426,1)=53;
  v2(426,2)=2863;
  v2(426,3)=(-(exp(y(38))*exp(y(14))))/T782;
  v2(427,1)=53;
  v2(427,2)=1039;
  v2(427,3)=  v2(426,3);
  v2(428,1)=53;
  v2(428,2)=2887;
  v2(428,3)=(T782*(-(exp(y(38))*exp(y(14))))-(-(exp(y(38))*exp(y(14))))*(T782+T782))/(T782*T782);
  v2(429,1)=53;
  v2(429,2)=4447;
  v2(429,3)=(-exp(y(58)));
  v2(430,1)=54;
  v2(430,2)=859;
  v2(430,3)=T564;
  v2(431,1)=54;
  v2(431,2)=2861;
  v2(431,3)=(-(exp(y(12))*exp(y(38))))/T782;
  v2(432,1)=54;
  v2(432,2)=885;
  v2(432,3)=  v2(431,3);
  v2(433,1)=54;
  v2(433,2)=2887;
  v2(433,3)=(T782*(-(exp(y(12))*exp(y(38))))-(-(exp(y(12))*exp(y(38))))*(T782+T782))/(T782*T782);
  v2(434,1)=54;
  v2(434,2)=4603;
  v2(434,3)=(-exp(y(60)));
  v2(435,1)=55;
  v2(435,2)=625;
  v2(435,3)=T570;
  v2(436,1)=55;
  v2(436,2)=2858;
  v2(436,3)=(-(exp(y(9))*exp(y(38))))/T782;
  v2(437,1)=55;
  v2(437,2)=654;
  v2(437,3)=  v2(436,3);
  v2(438,1)=55;
  v2(438,2)=2887;
  v2(438,3)=(T782*(-(exp(y(9))*exp(y(38))))-(-(exp(y(9))*exp(y(38))))*(T782+T782))/(T782*T782);
  v2(439,1)=55;
  v2(439,2)=4681;
  v2(439,3)=(-exp(y(61)));
  v2(440,1)=56;
  v2(440,2)=2887;
  v2(440,3)=(T782*(-(exp(y(38))*exp(y(53))))-(-(exp(y(38))*exp(y(53))))*(T782+T782))/(T782*T782);
  v2(441,1)=56;
  v2(441,2)=4042;
  v2(441,3)=(-(exp(y(38))*exp(y(53))))/T782;
  v2(442,1)=56;
  v2(442,2)=2902;
  v2(442,3)=  v2(441,3);
  v2(443,1)=56;
  v2(443,2)=4057;
  v2(443,3)=T576;
  v2(444,1)=56;
  v2(444,2)=4525;
  v2(444,3)=(-exp(y(59)));
  g2 = sparse(v2(:,1),v2(:,2),v2(:,3),56,5929);
end
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],56,456533);
end
end
