warning 'off';

% close all; clc; 
% clear; 

% delete('*.mat','*.pdf', '*.asv','*.fig','*.eps','cacciaFiori.m','cacciaFioriDeterministic.m','*_dynamic.m','*_static.m','*.txt','*.bin',...
%        '*.cod', '*.jnl','*.log','*_set_auxiliary_variables.m','cycle_irf.m','cycle_moments.m','transition.m');

addpath C:\dynare\4.4.3\matlab

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% CHOOSE OPTIONS
deterministicI      =      1;                            %% -- set to one if you want transition dynamics following deregulation
                                                                 %  -- otherwise: IRFs/second moments following a productivity shock

reformI             =      1;                            %% -- set to one if you consider a market reform
                                                                 %  -- otherwise: regulation set at euro area level

momentsI            =      0*(1-deterministicI); %% -- set to one if you want second moments (for given level of regulation);
                                                                 %  -- always zero when considering transition dynamics.
                                                                 
save options deterministicI reformI momentsI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% CHOOSE REFORM
pmrI   = 1; fcI    = 0;  ubI   = 0;  
save reforms ubI fcI pmrI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% CALIBRATE THE MODEL AND GET INITIAL, RIGID STEADY STATE
calibration; 
% clear;
load options
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if deterministicI==0 && reformI==0 
   %% BUSINES CYCLE DYNAMICS FOR BENCHMARK CALIBRATION WITH HIGH REGULATION (EITHER IRF OR SECOND MOMENTS)
    
   if momentsI==0
      dynare cycle_irf; load options
   else
      dynare cycle_moments; load options
      second_moments;
   end    
%        clear; 
       load options
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


                          
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if reformI==1 
   %% COMPUTE STEADY STATE AFTER MARKET REFORM   
   newsteady; 
%    clear; 
   load options
          
   if deterministicI==0 
      %% BUSINES CYCLE DYNAMICS AFTER DEREGULATION (EITHER IRF OR SECOND MOMENTS)
   
      if momentsI==0
         dynare cycle_irf; load options
      else
         dynare cycle_moments; load options
        second_moments;
      end    
             
   else
      %% TRANSITION DYNAMICS AFTER DEREGULATION
       dynare transition 
       phi = 0:0.5:2;
       first_time = 1;
       for i=1:length(phi)
           if first_time
               set_param_value('phiP',phi(i));
               dynare transition.mod noclearall;
first_time = 0;
           else
    set_param_value('phiP',phi(i));
    info = simul(var_list_);
if info;
    disp(['Computation fails for phiP ='  num2str(phiP)]);
end;
           end
       end
   end
   
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% FOR TRANSITION DYNAMICS WHERE INIT VALUES ARE USED TO GENERATE THE IRFS - New
%Countercyclical phiP value  
% load reforms
% load steadyInitial 
% if pmrI==1 && fcI==0 && ubI==0
% if phiP ==-1;
% save steadyInitial_fr_CC1 c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save pmr_transition_irf_CC1 c u ikdata ik gdpIncomedata markup N fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
% end
% end
% 
% if fcI==1 && pmrI==0 && ubI==0
%     if phiP ==-1;
% save steadyInitial_fc_CC1 c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save fc_transition_irf_CC1 c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
% end 
% end
% 
% if pmrI==1 && fcI==1 && ubI==0
%      if phiP ==-1;
% save steadyInitial_joint_CC1 c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save joint_transition_irf_CC1 c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
%      end
% end
% 
% 
% %Procyclical phiP value  
% if pmrI==1 && fcI==0 && ubI==0
% if phiP ==1;
% save steadyInitial_fr_PC1 c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save pmr_transition_irf_PC1 c u ikdata ik gdpIncomedata markup N fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
% end
% end
% 
% if fcI==1 && pmrI==0 && ubI==0
%     if phiP ==1;
% save steadyInitial_fc_PC1 c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save fc_transition_irf_PC1 c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
% end 
% end
% 
% if pmrI==1 && fcI==1 && ubI==0
%      if phiP ==1;
% save steadyInitial_joint_PC1 c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save joint_transition_irf_PC1 c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
%      end     
% end
%% FOR TRANSITION DYNAMICS WHERE INIT VALUES ARE USED TO GENERATE THE IRFS
% load reforms
% load steadyInitial 
% 
% if pmrI==1 && fcI==0 && ubI==0
% save steadyInitial_fr c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save pmr_transition_irf c u ikdata ik gdpIncomedata markup N fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
% end
% 
% if fcI==1 && pmrI==0 && ubI==0
% save steadyInitial_fc c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save fc_transition_irf c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
% end 
% 
% if pmrI==1 && fcI==1 && ubI==0
% save steadyInitial_joint c_SSinit u_SSinit ik_SSinit gdpIncome_SSinit markup_SSinit N_SSinit Ne_SSinit fr_SSinit rpD_SSinit yfirm_SSinit s_SSinit q_SSinit v_SSinit rho_SSinit wdata_SSinit JC_SSinit JD_SSinit netJC_SSinit zc_SSinit m_SSinit ub_SSinit
% save joint_transition_irf c u ikdata ik gdpIncomedata markup N Ne fr rpD iedata yfirm s q v rho wdata JC JD netJC zc m ub
% end
  %% FOR CYCLE IRFS
load reforms
load steady
load calibration
load options
%% Countercyclical phiP value 
if  deterministicI==0 && pmrI==0 && fcI==0 &&  ubI==0;
    if phiP ==-1;
save u_SS_transition_EU_CC1 u_SS
save epsZ_EU_CC1 cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ zc_epsZ N_epsZ iedata_epsZ markup_epsZ m_epsZ v_epsZ q_epsZ ub_epsZ
    end
end 

if deterministicI==0 && pmrI==1 && fcI==1 &&  ubI==1;
    if phiP ==-1;
save u_SS_transition_US_CC1 u_SS
save epsZ_US cmdata_epsZ_CC1 u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ zc_epsZ N_epsZ iedata_epsZ markup_epsZ m_epsZ v_epsZ q_epsZ ub_epsZ
    end
end

% if pmrI==1 && fcI==0 &&  ubI==1;
% save u_SS_transition_fcEU u_SS
% save epsZ_fcEU cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ
% end
% 
% if pmrI==0 && fcI==1 &&  ubI==0;
% save u_SS_transition_fcUS u_SS
% save epsZ_fcUS cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ
% end

%% Procyclical phiP value 
if deterministicI==0 && pmrI==0 && fcI==0 && ubI==0;
    if phiP ==1;
save u_SS_transition_EU_PC1 u_SS
save epsZ_EU_PC1 cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ zc_epsZ N_epsZ iedata_epsZ markup_epsZ m_epsZ v_epsZ q_epsZ ub_epsZ
    end 
end 

if deterministicI==0 && pmrI==1 && fcI==1 && ubI==1;
    if phiP ==1;
save u_SS_transition_US_PC1 u_SS
save epsZ_US cmdata_epsZ_PC1 u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ zc_epsZ N_epsZ iedata_epsZ markup_epsZ m_epsZ v_epsZ q_epsZ ub_epsZ
    end
end

% if pmrI==1 && fcI==0 &&  ubI==1;
% save u_SS_transition_fcEU u_SS
% save epsZ_fcEU cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ
% end
% 
% if pmrI==0 && fcI==1 &&  ubI==0;
% save u_SS_transition_fcUS u_SS
% save epsZ_fcUS cmdata_epsZ u_epsZ ikdata_epsZ gdpIncomedata_epsZ wdata_epsZ N_epsZ iedata_epsZ markup_epsZ
% end